<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Sociable Pro
 * @since Sociable Pro 1.0.0
 * @return array An array of default values
 */

function sociable_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$sociable_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#000545',
		'header_tagline_color'			=> '#5c697a',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#ff7173',
		'colorscheme'					=> 'default',
		'theme_version'					=> 'lite-version',
		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,

		// excerpt options
		'long_excerpt_length'           => 22,
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s. ', '1: Year, 2: Site Title with home URL', 'sociable-pro' ), '[the-year]', '[site-link]' ) . esc_html__( 'All Rights Reserved | ', 'sociable-pro' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'sociable-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'sortable' 						=> 'slider,introduction,featured_product,recent_product,latest_product,cta,service,about,features,counter,clients,portfolio,instagram,popular,team,reason,youtube,subscription,blog',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'sociable-pro' ),
		'hide_date' 					=> false,
		'hide_author'					=> false,
		'hide_category'					=> false,
		'archive_column'				=> 'col-2',

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,
		'single_post_hide_author'		=> false,

		/* Front Page */

		// topbar
		'topbar_section_enable'			=> true,
		'topbar_email'					=> 'info@themepalace.com',
		'topbar_phone'					=> esc_html__( '+119 259 3514 451', 'sociable-pro' ),
		'topbar_address'					=> esc_html__( 'Kupandole, Nepal', 'sociable-pro' ),

		// Homepage Layout
		'home_layout'					=> 'default-design',

		// topbar
		'header_meta_social_enable'			=> false,

		// Slider
		'slider_section_enable'			=> false,
		'slider_content_type'			=> 'category',
		'slider_count'					=> 3,
		'slider_btn_label'				=> esc_html__( 'Learn More', 'sociable-pro' ),

		// Introduction
		'introduction_section_enable'	=> true,
		'introduction_content_type'		=> 'page',
		'introduction_sub_title'		=> esc_html__( 'Hello, I am', 'sociable-pro' ),
		'introduction_title'			=> esc_html__( 'Lucie Anderson', 'sociable-pro' ),
		'introduction_description'		=> esc_html__( 'We shape and activate brands through insight, vision and execution.', 'sociable-pro' ),
		'introduction_btn_title'		=> esc_html__( 'About Me', 'sociable-pro' ),

		// service
		'service_section_enable'		=> true,
		'service_content_type'			=> 'category',
		'service_count'					=> 6,
		'service_column'				=> 'col-3',
		'service_title'					=> esc_html__( 'Make Successful Business', 'sociable-pro' ),
		'service_subtitle'				=> esc_html__( 'Business consulting excepteur sint occaecat cupidatat consulting non proident, sunt in culpa qui officia deserunt laborum Market.', 'sociable-pro' ), 

		// About
		'about_section_enable'			=> true,
		'about_content_type'			=> 'page',
		'about_title'					=> esc_html__( 'Analysis and Consulting', 'sociable-pro' ),
		'about_description'				=> esc_html__( 'Lorem ipsum dolor sit amet, con sectetur adipiscing elit. Etiam euismod pulvinar velit id commodo. Aenean id varius libLorem ipsum dolor sit amet, consectetur adipiscing elit. Etiam euismod pulvinar velit id commodo. Aenean id varius libero. Curabitur sit amet eros velit. Fusce sed cursus quam. Nam sit amet sapien eu lorem fringilla ullamcorper. Integer fermentum erat gravida, sagittis quam in, condimentum ligula.', 'sociable-pro' ),

		// Clients
		'clients_section_enable'		=> true,
		'clients_content_type'			=> 'page',
		'clients_column'				=> 'col-5',
		'clients_count'					=> 5,

		// cta
		'cta_section_enable'		=> true,
		'cta_content_type'			=> 'page',
		'cta_title'					=> esc_html__( 'Analysis and Consulting', 'sociable-pro' ),
		'cta_btn_title'				=> esc_html__( 'Read More', 'sociable-pro' ),


		//featured product
		'featured_product_section_enable'		=> true,
		'featured_product_count'				=> 3,

		'recent_product_section_enable'		=> true,
		'recent_product_content_type'		=> 'product',
		'recent_product_count'				=> 4,
		'recent_product_title'				=> esc_html__( 'Recent Products', 'sociable-pro' ),
		'recent_product_sub_title'			=> esc_html__( 'Latest spring collection for fashionable person like you.', 'sociable-pro' ),

		'latest_product_section_enable'		=> true,
		'latest_product_content_type'		=> 'product',
		'latest_product_count'				=> 4,
		'latest_product_title'				=> esc_html__( 'latest Products', 'sociable-pro' ),
		'latest_product_sub_title'			=> esc_html__( 'Latest spring collection for fashionable person like you.', 'sociable-pro' ),

		// counter
		'counter_section_enable'		=> true,
		'counter_count'					=> 4,
		'counter_column'				=> 'col-4',
		'counter_content_icon_1'		=> esc_html__( 'fa-user', 'sociable-pro' ),
		'counter_title_1'				=> esc_html__( 'Users', 'sociable-pro' ),
		'counter_number_1'				=> esc_html__( '1500+', 'sociable-pro' ),
		'counter_content_icon_2'		=> esc_html__( 'fa-book', 'sociable-pro' ),
		'counter_title_2'				=> esc_html__( 'Projects', 'sociable-pro' ),
		'counter_number_2'				=> esc_html__( '50', 'sociable-pro' ),
		'counter_content_icon_3'		=> esc_html__( 'fa-users', 'sociable-pro' ),
		'counter_title_3'				=> esc_html__( 'Progress', 'sociable-pro' ),
		'counter_number_3'				=> esc_html__( '150', 'sociable-pro' ),
		'counter_content_icon_4'		=> esc_html__( 'fa-trophy', 'sociable-pro' ),
		'counter_title_4'				=> esc_html__( 'Awards', 'sociable-pro' ),
		'counter_number_4'				=> esc_html__( '150', 'sociable-pro' ),
		'counter_image'					=> get_template_directory_uri() . '/assets/uploads/counter.jpg',

		// Portfolio
		'portfolio_section_enable'		=> true,
		'portfolio_count'				=> 10,
		'portfolio_icon'				=> 'fa-briefcase',
		'portfolio_title'				=> esc_html__( 'Our Projects', 'sociable-pro' ),
		'portfolio_description'			=> esc_html__( 'Meagan Fisher is an English actress, model and activist. She was born in Paris and brought up in Oxfordshire, Watson attended the Dragon School and trained as an acress at Oxforf branch of Stage coach Theatre Arts.', 'sociable-pro' ),
		'portfolio_btn_label'			=> esc_html__( 'View All Projects', 'sociable-pro' ),

		// feature
		'features_section_enable'		=> false,
		'features_content_type'			=> 'category',
		'features_count'				=> 6,
		'features_column'				=> 'col-3',
		'features_title'				=> esc_html__( 'Make Successful Business', 'sociable-pro' ),
		'features_subtitle'				=> esc_html__( 'Business consulting excepteur sint occaecat cupidatat consulting non proident, sunt in culpa qui officia deserunt laborum Market.', 'sociable-pro' ), 

		// Instagram
		'instagram_section_enable'		=> true,
		'instagram_count'				=> 12,
		'instagram_column_type'			=> 4,
		'instagram_icon'				=> 'fa-instagram',
		'instagram_title'				=> esc_html__( 'Present yourself in Instagram', 'sociable-pro' ),
		'instagram_description'			=> esc_html__( 'Meagan Fisher is an English actress, model and activist. She was born in Paris and brought up in Oxfordshire, Watson attended the Dragon School and trained as an acress at Oxforf branch of Stage coach Theatre Arts.', 'sociable-pro' ),
		'instagram_btn_label'			=> esc_html__( 'Follow On Instagram', 'sociable-pro' ),

		// team
		'team_section_enable'		=> false,
		'team_content_type'			=> 'category',
		'team_count'					=> 4,
		'team_title'					=> esc_html__( 'Our Team', 'sociable-pro' ),
		'team_sub_title'				=> esc_html__( 'A cultural icon is a person or artifact that is recognized by members of a culture or sub-culture as representing some aspect of cultural identity.', 'sociable-pro' ),

		// Reason
		'reason_section_enable'			=> true,
		'reason_background_image'		=> '',
		'reason_content_type'			=> 'page',
		'reason_title'					=> esc_html__( 'Analysis and Consulting', 'sociable-pro' ),
		'reason_description'			=> esc_html__( 'Lorem ipsum dolor sit amet, con sectetur adipiscing elit. Etiam euismod pulvinar velit id commodo. Aenean id varius libLorem ipsum dolor sit amet, consectetur adipiscing elit. Etiam euismod pulvinar velit id commodo. Aenean id varius libero. Curabitur sit amet eros velit. Fusce sed cursus quam. Nam sit amet sapien eu lorem fringilla ullamcorper. Integer fermentum erat gravida, sagittis quam in, condimentum ligula.', 'sociable-pro' ),

		// Youtube
		'youtube_section_enable'		=> false,
		'youtube_count'					=> 4,
		'youtube_column_type'			=> 'col-4',
		'youtube_icon'					=> 'fa-youtube-play',
		'youtube_title'					=> esc_html__( 'Watch my video in Youtube', 'sociable-pro' ),
		'youtube_description'			=> esc_html__( 'Meagan Fisher is an English actress, model and activist. She was born in Paris and brought up in Oxfordshire, Watson attended the Dragon School and trained as an acress at Oxforf branch of Stage coach Theatre Arts.', 'sociable-pro' ),
		'youtube_btn_label'				=> esc_html__( 'Subscribe on Youtube', 'sociable-pro' ),

		// blog
		'blog_section_enable'			=> true,
		'blog_content_type'				=> 'recent',
		'blog_count'					=> 3,
		'blog_column'					=> 'col-3',
		'blog_icon'						=> 'fa-newspaper-o',
		'blog_title'					=> esc_html__( 'Latest Articles', 'sociable-pro' ),
		'blog_description'				=> esc_html__( 'Meagan Fisher is an English actress, model and activist. She was born in Paris and brought up in Oxfordshire, Watson attended the Dragon School and trained as an acress at Oxforf branch of Stage coach Theatre Arts.', 'sociable-pro' ),
		'blog_btn_title'				=> esc_html__( 'View All Articles', 'sociable-pro' ),

		// popular
		'popular_section_enable'			=> true,
		'popular_content_type'				=> 'recent',
		'popular_count'						=> 4,
		'popular_column'					=> 'col-4',
		'popular_icon'						=> 'fa-newspaper-o',
		'popular_title'						=> esc_html__( 'Popular Articles', 'sociable-pro' ),

		// Subscription
		'subscription_section_enable'	=> true,
		'subscription_sub_title'		=> esc_html__( 'Newsletter', 'sociable-pro' ),
		'subscription_title'			=> esc_html__( 'Stay informed', 'sociable-pro' ),
		'subscription_btn_label'		=> esc_html__( 'Subscribe Now', 'sociable-pro' ),

	);

	$output = apply_filters( 'sociable_pro_default_theme_options', $sociable_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}