<?php
/**
 * Clients Section options
 *
 * @package Theme Palace
 * @subpackage Sociable Pro
 * @since Sociable Pro 1.0.0
 */

// Add Clients section
$wp_customize->add_section( 'sociable_pro_clients_section', array(
	'title'             => esc_html__( 'Clients','sociable-pro' ),
	'description'       => esc_html__( 'Clients Section options.', 'sociable-pro' ),
	'panel'             => 'sociable_pro_front_page_panel',
	'active_callback'	=> 'sociable_pro_is_client_design_enable',
) );

// Clients content enable control and setting
$wp_customize->add_setting( 'sociable_pro_theme_options[clients_section_enable]', array(
	'default'			=> 	$options['clients_section_enable'],
	'sanitize_callback' => 'sociable_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Sociable_Pro_Switch_Control( $wp_customize, 'sociable_pro_theme_options[clients_section_enable]', array(
	'label'             => esc_html__( 'Clients Section Enable', 'sociable-pro' ),
	'section'           => 'sociable_pro_clients_section',
	'on_off_label' 		=> sociable_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sociable_pro_theme_options[clients_section_enable]', array(
		'selector'            => '#our-partners .tooltiptext',
		'settings'            => 'sociable_pro_theme_options[clients_section_enable]',
    ) );
}


// Event social icons number control and setting
$wp_customize->add_setting( 'sociable_pro_theme_options[clients_count]', array(
	'default'          	=> $options['clients_count'],
	'sanitize_callback' => 'sociable_pro_sanitize_number_range',
	'validate_callback' => 'sociable_pro_validate_clients_count',
) );

// Clients content type control and setting
$wp_customize->add_setting( 'sociable_pro_theme_options[clients_column]', array(
	'default'          	=> $options['clients_column'],
	'sanitize_callback' => 'sociable_pro_sanitize_select',
) );

$wp_customize->add_control( 'sociable_pro_theme_options[clients_column]', array(
	'label'             => esc_html__( 'Column Layout', 'sociable-pro' ),
	'section'           => 'sociable_pro_clients_section',
	'type'				=> 'select',
	'active_callback' 	=> 'sociable_pro_is_clients_section_enable',
	'choices'			=> array( 
		'col-1' 		=> esc_html__( 'One Column', 'sociable-pro' ),
		'col-2' 		=> esc_html__( 'Two Column', 'sociable-pro' ),
		'col-3' 		=> esc_html__( 'Three Column', 'sociable-pro' ),
		'col-4' 		=> esc_html__( 'Four Column', 'sociable-pro' ),
		'col-5' 		=> esc_html__( 'Five Column', 'sociable-pro' ),
		'col-6' 		=> esc_html__( 'Six Column', 'sociable-pro' ),
	),
) );

$wp_customize->add_control( 'sociable_pro_theme_options[clients_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'sociable-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 8. Please input the valid number and save. Then refresh the page to see the change.', 'sociable-pro' ),
	'section'           => 'sociable_pro_clients_section',
	'active_callback'   => 'sociable_pro_is_clients_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 8,
		'style' => 'width: 100px;'
		),
) );

// Clients content type control and setting
$wp_customize->add_setting( 'sociable_pro_theme_options[clients_content_type]', array(
	'default'          	=> $options['clients_content_type'],
	'sanitize_callback' => 'sociable_pro_sanitize_select',
) );

$wp_customize->add_control( 'sociable_pro_theme_options[clients_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'sociable-pro' ),
	'section'           => 'sociable_pro_clients_section',
	'type'				=> 'select',
	'active_callback' 	=> 'sociable_pro_is_clients_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'sociable-pro' ),
		'post' 		=> esc_html__( 'Post', 'sociable-pro' ),
		'category' 	=> esc_html__( 'Category', 'sociable-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'sociable-pro' ),
	),
) );

for ( $i = 1; $i <= $options['clients_count']; $i++ ) :
	// clients pages drop down chooser control and setting
	$wp_customize->add_setting( 'sociable_pro_theme_options[clients_content_page_' . $i . ']', array(
		'sanitize_callback' => 'sociable_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Sociable_Pro_Dropdown_Chooser( $wp_customize, 'sociable_pro_theme_options[clients_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'sociable-pro' ), $i ),
		'section'           => 'sociable_pro_clients_section',
		'choices'			=> sociable_pro_page_choices(),
		'active_callback'	=> 'sociable_pro_is_clients_section_content_page_enable',
	) ) );

	// clients posts drop down chooser control and setting
	$wp_customize->add_setting( 'sociable_pro_theme_options[clients_content_post_' . $i . ']', array(
		'sanitize_callback' => 'sociable_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Sociable_Pro_Dropdown_Chooser( $wp_customize, 'sociable_pro_theme_options[clients_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'sociable-pro' ), $i ),
		'section'           => 'sociable_pro_clients_section',
		'choices'			=> sociable_pro_post_choices(),
		'active_callback'	=> 'sociable_pro_is_clients_section_content_post_enable',
	) ) );

	// Clients image setting and control.
	$wp_customize->add_setting( 'sociable_pro_theme_options[clients_image_' . $i . ']', array(
		'sanitize_callback' => 'sociable_pro_sanitize_image',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'sociable_pro_theme_options[clients_image_' . $i . ']',
			array(
			'label'       		=> sprintf( esc_html__( 'Image %d', 'sociable-pro' ), $i),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'sociable-pro' ), 200, 60 ),
			'section'     		=> 'sociable_pro_clients_section',
			'active_callback'	=> 'sociable_pro_is_clients_section_content_custom_enable',
	) ) );

	// Clients title setting and control
	$wp_customize->add_setting( 'sociable_pro_theme_options[clients_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'sociable_pro_theme_options[clients_title_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Clients Title %d', 'sociable-pro' ), $i),
		'section'        	=> 'sociable_pro_clients_section',
		'active_callback' 	=> 'sociable_pro_is_clients_section_content_custom_enable',
		'type'				=> 'text',
	) );

	// Clients url setting and control
	$wp_customize->add_setting( 'sociable_pro_theme_options[clients_url_' . $i . ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'sociable_pro_theme_options[clients_url_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Clients Url %d', 'sociable-pro' ), $i),
		'section'        	=> 'sociable_pro_clients_section',
		'active_callback' 	=> 'sociable_pro_is_clients_section_content_custom_enable',
		'type'				=> 'url',
	) );

	// clients hr setting and control
	$wp_customize->add_setting( 'sociable_pro_theme_options[clients_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Sociable_Pro_Customize_Horizontal_Line( $wp_customize, 'sociable_pro_theme_options[clients_hr_'. $i .']',
		array(
			'section'         => 'sociable_pro_clients_section',
			'active_callback' => 'sociable_pro_is_clients_section_content_custom_enable',
			'type'			  => 'hr'
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'sociable_pro_theme_options[clients_content_category]', array(
	'sanitize_callback' => 'sociable_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Sociable_Pro_Dropdown_Taxonomies_Control( $wp_customize,'sociable_pro_theme_options[clients_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'sociable-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'sociable-pro' ),
	'section'           => 'sociable_pro_clients_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'sociable_pro_is_clients_section_content_category_enable'
) ) );