<?php
/**
 * Call To Action Section options
 *
 * @package Theme Palace
 * @subpackage sociable Pro
 * @since sociable Pro 1.0.0
 */

// Add Call To Action section
$wp_customize->add_section( 'sociable_pro_cta_section', array(
    'title'             => esc_html__( 'Call To Action','sociable-pro' ),
    'description'       => esc_html__( 'Call To Action Section options.', 'sociable-pro' ),
    'panel'             => 'sociable_pro_front_page_panel',
    'active_callback'   => 'sociable_pro_is_cta_design_enable',
) );

// Call To Action content enable control and setting
$wp_customize->add_setting( 'sociable_pro_theme_options[cta_section_enable]', array(
    'default'           =>  $options['cta_section_enable'],
    'sanitize_callback' => 'sociable_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Sociable_Pro_Switch_Control( $wp_customize, 'sociable_pro_theme_options[cta_section_enable]', array(
    'label'             => esc_html__( 'Call To Action Section Enable', 'sociable-pro' ),
    'section'           => 'sociable_pro_cta_section',
    'on_off_label'      => sociable_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sociable_pro_theme_options[cta_section_enable]', array(
        'selector'            => '#cta .tooltiptext',
        'settings'            => 'sociable_pro_theme_options[cta_section_enable]',
    ) );
}

// Call To Action content type control and setting
$wp_customize->add_setting( 'sociable_pro_theme_options[cta_content_type]', array(
    'default'           => $options['cta_content_type'],
    'sanitize_callback' => 'sociable_pro_sanitize_select',
) );

$wp_customize->add_control( 'sociable_pro_theme_options[cta_content_type]', array(
    'label'             => esc_html__( 'Content Type', 'sociable-pro' ),
    'section'           => 'sociable_pro_cta_section',
    'type'              => 'select',
    'active_callback'   => 'sociable_pro_is_cta_section_enable',
    'choices'           => array( 
        'page'      => esc_html__( 'Page', 'sociable-pro' ),
        'post'      => esc_html__( 'Post', 'sociable-pro' ),
        'custom'    => esc_html__( 'Custom', 'sociable-pro' ),
    ),
) );

// cta pages drop down chooser control and setting
$wp_customize->add_setting( 'sociable_pro_theme_options[cta_content_page]', array(
    'sanitize_callback' => 'sociable_pro_sanitize_page',
) );

$wp_customize->add_control( new Sociable_Pro_Dropdown_Chooser( $wp_customize, 'sociable_pro_theme_options[cta_content_page]', array(
    'label'             => esc_html__( 'Select Page', 'sociable-pro' ),
    'section'           => 'sociable_pro_cta_section',
    'choices'           => sociable_pro_page_choices(),
    'active_callback'   => 'sociable_pro_is_cta_section_content_page_enable',
) ) );

// cta posts drop down chooser control and setting
$wp_customize->add_setting( 'sociable_pro_theme_options[cta_content_post]', array(
    'sanitize_callback' => 'sociable_pro_sanitize_page',
) );

$wp_customize->add_control( new Sociable_Pro_Dropdown_Chooser( $wp_customize, 'sociable_pro_theme_options[cta_content_post]', array(
    'label'             => esc_html__( 'Select Post', 'sociable-pro' ),
    'section'           => 'sociable_pro_cta_section',
    'choices'           => sociable_pro_post_choices(),
    'active_callback'   => 'sociable_pro_is_cta_section_content_post_enable',
) ) );

// cta title setting and control
$wp_customize->add_setting( 'sociable_pro_theme_options[cta_title]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['cta_title'],
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'sociable_pro_theme_options[cta_title]', array(
    'label'             => esc_html__( 'Title', 'sociable-pro' ),
    'section'           => 'sociable_pro_cta_section',
    'active_callback'   => 'sociable_pro_is_cta_section_content_custom_enable',
    'type'              => 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sociable_pro_theme_options[cta_title]', array(
        'selector'            => '#call-to-action .entry-header h2',
        'settings'            => 'sociable_pro_theme_options[cta_title]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'sociable_pro_cta_title_partial',
    ) );
}

// cta btn title setting and control
$wp_customize->add_setting( 'sociable_pro_theme_options[cta_btn_title]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['cta_btn_title'],
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'sociable_pro_theme_options[cta_btn_title]', array(
    'label'             => esc_html__( 'Button Label', 'sociable-pro' ),
    'section'           => 'sociable_pro_cta_section',
    'active_callback'   => 'sociable_pro_is_cta_section_enable',
    'type'              => 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sociable_pro_theme_options[cta_btn_title]', array(
        'selector'            => '#cta a.btn',
        'settings'            => 'sociable_pro_theme_options[cta_btn_title]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'sociable_pro_cta_btn_title_partial',
    ) );
}

$wp_customize->add_setting( 'sociable_pro_theme_options[cta_image]', array(
    'sanitize_callback' => 'sociable_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'sociable_pro_theme_options[cta_image]',
        array(
        'label'             => esc_html__( 'Image', 'sociable-pro' ),
        'section'           => 'sociable_pro_cta_section',
        'active_callback'   => 'sociable_pro_is_cta_section_content_custom_enable',
) ) );

// cta btn link setting and control
$wp_customize->add_setting( 'sociable_pro_theme_options[cta_btn_link]', array(
    'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'sociable_pro_theme_options[cta_btn_link]', array(
    'label'             => esc_html__( 'Button Link', 'sociable-pro' ),
    'section'           => 'sociable_pro_cta_section',
    'active_callback'   => 'sociable_pro_is_cta_section_content_custom_enable',
    'type'              => 'url',
) );
