<?php
/**
 * featured_product Section options
 *
 * @package Theme Palace
 * @subpackage Sociable Pro
 * @since Sociable Pro 1.0.0
 */

// Add featured_product section
$wp_customize->add_section( 'sociable_pro_featured_product_section', array(
	'title'             => esc_html__( 'Featured Product','sociable-pro' ),
	'description'       => esc_html__( 'Featured Product Section options.', 'sociable-pro' ),
	'panel'             => 'sociable_pro_front_page_panel',
	'active_callback'	=> 'sociable_pro_is_featured_product_design_enable',
) );

// featured_product content enable control and setting
$wp_customize->add_setting( 'sociable_pro_theme_options[featured_product_section_enable]', array(
	'default'			=> 	$options['featured_product_section_enable'],
	'sanitize_callback' => 'sociable_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Sociable_Pro_Switch_Control( $wp_customize, 'sociable_pro_theme_options[featured_product_section_enable]', array(
	'label'             => esc_html__( 'Featured Product Section Enable', 'sociable-pro' ),
	'section'           => 'sociable_pro_featured_product_section',
	'on_off_label' 		=> sociable_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sociable_pro_theme_options[featured_product_section_enable]', array(
		'selector'            => '#featured-products .tooltiptext',
		'settings'            => 'sociable_pro_theme_options[featured_product_section_enable]',
    ) );
}


// Event social icons number control and setting
$wp_customize->add_setting( 'sociable_pro_theme_options[featured_product_count]', array(
	'default'          	=> $options['featured_product_count'],
	'sanitize_callback' => 'sociable_pro_sanitize_number_range',
	'validate_callback' => 'sociable_pro_validate_featured_product_count',
) );

$wp_customize->add_control( 'sociable_pro_theme_options[featured_product_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'sociable-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 9. Please input the valid number and save. Then refresh the page to see the change.', 'sociable-pro' ),
	'section'           => 'sociable_pro_featured_product_section',
	'active_callback'   => 'sociable_pro_is_featured_product_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 9,
		'style' => 'width: 100px;'
		),
) );


for ( $i = 1; $i <= $options['featured_product_count']; $i++ ) :

	// featured_product image setting and control.
	$wp_customize->add_setting( 'sociable_pro_theme_options[featured_product_image_' . $i . ']', array(
		'sanitize_callback' => 'sociable_pro_sanitize_image',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'sociable_pro_theme_options[featured_product_image_' . $i . ']',
			array(
			'label'       		=> sprintf( esc_html__( 'Image %d', 'sociable-pro' ), $i),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'sociable-pro' ), 200, 60 ),
			'section'     		=> 'sociable_pro_featured_product_section',
			'active_callback'	=> 'sociable_pro_is_featured_product_section_enable',
	) ) );

	// featured_product title setting and control
	$wp_customize->add_setting( 'sociable_pro_theme_options[featured_product_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'sociable_pro_theme_options[featured_product_title_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Featured Product Title %d', 'sociable-pro' ), $i),
		'section'        	=> 'sociable_pro_featured_product_section',
		'active_callback' 	=> 'sociable_pro_is_featured_product_section_enable',
		'type'				=> 'text',
	) );	

	// featured_product title setting and control
	$wp_customize->add_setting( 'sociable_pro_theme_options[featured_product_sub_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'sociable_pro_theme_options[featured_product_sub_title_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Featured Sub Product Title %d', 'sociable-pro' ), $i),
		'section'        	=> 'sociable_pro_featured_product_section',
		'active_callback' 	=> 'sociable_pro_is_featured_product_section_enable',
		'type'				=> 'text',
	) );

	// featured_product url setting and control
	$wp_customize->add_setting( 'sociable_pro_theme_options[featured_product_url_' . $i . ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'sociable_pro_theme_options[featured_product_url_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Featured Product Url %d', 'sociable-pro' ), $i),
		'section'        	=> 'sociable_pro_featured_product_section',
		'active_callback' 	=> 'sociable_pro_is_featured_product_section_enable',
		'type'				=> 'url',
	) );

	// featured_product hr setting and control
	$wp_customize->add_setting( 'sociable_pro_theme_options[featured_product_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Sociable_Pro_Customize_Horizontal_Line( $wp_customize, 'sociable_pro_theme_options[featured_product_hr_'. $i .']',
		array(
			'section'         => 'sociable_pro_featured_product_section',
			'active_callback' => 'sociable_pro_is_featured_product_section_enable',
			'type'			  => 'hr'
	) ) );

endfor;
