<?php
/**
 * Feature Section options
 *
 * @package Theme Palace
 * @subpackage Sociable Pro
 * @since Sociable Pro 1.0.0
 */

// Add Feature section
$wp_customize->add_section( 'sociable_pro_features_section', array(
	'title'             => esc_html__( 'Features','sociable-pro' ),
	'description'       => esc_html__( 'Features Section options.', 'sociable-pro' ),
	'panel'             => 'sociable_pro_front_page_panel',
	'active_callback'	=> 'sociable_pro_is_features_design_enable',
) );

// Feature content enable control and setting
$wp_customize->add_setting( 'sociable_pro_theme_options[features_section_enable]', array(
	'default'			=> 	$options['features_section_enable'],
	'sanitize_callback' => 'sociable_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Sociable_Pro_Switch_Control( $wp_customize, 'sociable_pro_theme_options[features_section_enable]', array(
	'label'             => esc_html__( 'Feature Section Enable', 'sociable-pro' ),
	'section'           => 'sociable_pro_features_section',
	'on_off_label' 		=> sociable_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sociable_pro_theme_options[features_section_enable]', array(
		'selector'            => '.features .tooltiptext',
		'settings'            => 'sociable_pro_theme_options[features_section_enable]',
    ) );
}


// features subtitle setting and control
$wp_customize->add_setting( 'sociable_pro_theme_options[features_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['features_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'sociable_pro_theme_options[features_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'sociable-pro' ),
	'section'        	=> 'sociable_pro_features_section',
	'active_callback' 	=> 'sociable_pro_is_features_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sociable_pro_theme_options[features_subtitle]', array(
		'selector'            => '#our-featuress .section-header span.custom-meta-title',
		'settings'            => 'sociable_pro_theme_options[features_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'sociable_pro_features_subtitle_partial',
    ) );
}

// features title setting and control
$wp_customize->add_setting( 'sociable_pro_theme_options[features_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['features_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'sociable_pro_theme_options[features_title]', array(
	'label'           	=> esc_html__( 'Title', 'sociable-pro' ),
	'section'        	=> 'sociable_pro_features_section',
	'active_callback' 	=> 'sociable_pro_is_features_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sociable_pro_theme_options[features_title]', array(
		'selector'            => '#our-featuress .section-header h2.section-title',
		'settings'            => 'sociable_pro_theme_options[features_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'sociable_pro_features_title_partial',
    ) );
}

// features note control and setting
$wp_customize->add_setting( 'sociable_pro_theme_options[features_column]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['features_column'],
) );

$wp_customize->add_control( 'sociable_pro_theme_options[features_column]', array(
	'label'             => esc_html__( 'Column Layout', 'sociable-pro' ),
	'section'           => 'sociable_pro_features_section',
	'type'				=> 'select',
	'active_callback' 	=> 'sociable_pro_is_features_section_enable',
	'choices'			=> array( 
		'col-2'		=> esc_html__( 'Two Column', 'sociable-pro' ),
		'col-3'		=> esc_html__( 'Three Column', 'sociable-pro' ),
		'col-4'		=> esc_html__( 'Four Column', 'sociable-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'sociable_pro_theme_options[features_count]', array(
	'default'          	=> $options['features_count'],
	'sanitize_callback' => 'sociable_pro_sanitize_number_range',
	'validate_callback' => 'sociable_pro_validate_features_count',
) );

$wp_customize->add_control( 'sociable_pro_theme_options[features_count]', array(
	'label'             => esc_html__( 'Number of Features', 'sociable-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'sociable-pro' ),
	'section'           => 'sociable_pro_features_section',
	'active_callback'   => 'sociable_pro_is_features_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 2,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Feature content type control and setting
$wp_customize->add_setting( 'sociable_pro_theme_options[features_content_type]', array(
	'default'          	=> $options['features_content_type'],
	'sanitize_callback' => 'sociable_pro_sanitize_select',
) );

$wp_customize->add_control( 'sociable_pro_theme_options[features_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'sociable-pro' ),
	'section'           => 'sociable_pro_features_section',
	'type'				=> 'select',
	'active_callback' 	=> 'sociable_pro_is_features_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'sociable-pro' ),
		'post' 		=> esc_html__( 'Post', 'sociable-pro' ),
		'category' 	=> esc_html__( 'Category', 'sociable-pro' ),
	),
) );

for ( $i = 1; $i <= $options['features_count']; $i++ ) :

	// features note control and setting
	$wp_customize->add_setting( 'sociable_pro_theme_options[features_content_icon_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Sociable_Pro_Icon_Picker( $wp_customize, 'sociable_pro_theme_options[features_content_icon_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Icon %d', 'sociable-pro' ), $i ),
		'section'           => 'sociable_pro_features_section',
		'active_callback'	=> 'sociable_pro_is_features_section_enable',
	) ) );

	// features pages drop down chooser control and setting
	$wp_customize->add_setting( 'sociable_pro_theme_options[features_content_page_' . $i . ']', array(
		'sanitize_callback' => 'sociable_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Sociable_Pro_Dropdown_Chooser( $wp_customize, 'sociable_pro_theme_options[features_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'sociable-pro' ), $i ),
		'section'           => 'sociable_pro_features_section',
		'choices'			=> sociable_pro_page_choices(),
		'active_callback'	=> 'sociable_pro_is_features_section_content_page_enable',
	) ) );

	// features posts drop down chooser control and setting
	$wp_customize->add_setting( 'sociable_pro_theme_options[features_content_post_' . $i . ']', array(
		'sanitize_callback' => 'sociable_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Sociable_Pro_Dropdown_Chooser( $wp_customize, 'sociable_pro_theme_options[features_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'sociable-pro' ), $i ),
		'section'           => 'sociable_pro_features_section',
		'choices'			=> sociable_pro_post_choices(),
		'active_callback'	=> 'sociable_pro_is_features_section_content_post_enable',
	) ) );

	// features hr setting and control
	$wp_customize->add_setting( 'sociable_pro_theme_options[features_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Sociable_Pro_Customize_Horizontal_Line( $wp_customize, 'sociable_pro_theme_options[features_hr_'. $i .']',
		array(
			'section'         => 'sociable_pro_features_section',
			'active_callback' => 'sociable_pro_is_features_section_content_seperator_enable',
			'type'			  => 'hr'
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'sociable_pro_theme_options[features_content_category]', array(
	'sanitize_callback' => 'sociable_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Sociable_Pro_Dropdown_Taxonomies_Control( $wp_customize,'sociable_pro_theme_options[features_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'sociable-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'sociable-pro' ),
	'section'           => 'sociable_pro_features_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'sociable_pro_is_features_section_content_category_enable'
) ) );
