<?php
/**
 * Instagram Section options
 *
 * @package Theme Palace
 * @subpackage Sociable Pro
 * @since Sociable Pro 1.0.0
 */

// Add Instagram section
$wp_customize->add_section( 'sociable_pro_instagram_section', array(
	'title'             => esc_html__( 'Instagram','sociable-pro' ),
	'description'       => sprintf( sociable_pro_santize_allow_tag('Instagram Section options. <a href="%1$s">click here </a> to link instagram account', 'sociable-pro'), admin_url( $path = '?page=sb-instagram-feed', $scheme = 'admin' ) ),
	'panel'             => 'sociable_pro_front_page_panel',
	'active_callback' 	=> 'sociable_pro_is_instagram_design_enable',
) );

// Instagram content enable control and setting
$wp_customize->add_setting( 'sociable_pro_theme_options[instagram_section_enable]', array(
	'default'			=> 	$options['instagram_section_enable'],
	'sanitize_callback' => 'sociable_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Sociable_Pro_Switch_Control( $wp_customize, 'sociable_pro_theme_options[instagram_section_enable]', array(
	'label'             => esc_html__( 'Instagram Section Enable', 'sociable-pro' ),
	'section'           => 'sociable_pro_instagram_section',
	'on_off_label' 		=> sociable_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sociable_pro_theme_options[instagram_section_enable]', array(
		'selector'            => '#instagram-section .tooltiptext',
		'settings'            => 'sociable_pro_theme_options[instagram_section_enable]',
    ) );
}


$wp_customize->add_setting( 'sociable_pro_theme_options[instagram_icon]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['instagram_icon'],
) );

$wp_customize->add_control( new Sociable_Pro_Icon_Picker( $wp_customize, 'sociable_pro_theme_options[instagram_icon]', array(
	'label'             => esc_html__( 'Select Icon', 'sociable-pro' ),
	'section'           => 'sociable_pro_instagram_section',
	'active_callback'	=> 'sociable_pro_is_instagram_section_enable',
) ) );

// Instagram title setting and control
$wp_customize->add_setting( 'sociable_pro_theme_options[instagram_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['instagram_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'sociable_pro_theme_options[instagram_title]', array(
	'label'           	=> esc_html__( 'Instagram Title', 'sociable-pro' ),
	'section'        	=> 'sociable_pro_instagram_section',
	'active_callback' 	=> 'sociable_pro_is_instagram_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sociable_pro_theme_options[instagram_title]', array(
		'selector'            => '#instagram-section .section-header h2.section-title',
		'settings'            => 'sociable_pro_theme_options[instagram_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'sociable_pro_instagram_title_partial',
    ) );
}

// Instagram description setting and control
$wp_customize->add_setting( 'sociable_pro_theme_options[instagram_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['instagram_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'sociable_pro_theme_options[instagram_description]', array(
	'label'           	=> esc_html__( 'Instagram Description', 'sociable-pro' ),
	'section'        	=> 'sociable_pro_instagram_section',
	'active_callback' 	=> 'sociable_pro_is_instagram_section_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sociable_pro_theme_options[instagram_description]', array(
		'selector'            => '#instagram-section .section-subtitle p',
		'settings'            => 'sociable_pro_theme_options[instagram_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'sociable_pro_instagram_description_partial',
    ) );
}

