<?php
/**
 * Introduction Section options
 *
 * @package Theme Palace
 * @subpackage Sociable Pro
 * @since Sociable Pro 1.0.0
 */

// Add Introduction section
$wp_customize->add_section( 'sociable_pro_introduction_section', array(
	'title'             => esc_html__( 'Introduction','sociable-pro' ),
	'description'       => esc_html__( 'Introduction Section options.', 'sociable-pro' ),
	'panel'             => 'sociable_pro_front_page_panel',
	'active_callback'	=>'sociable_pro_is_introduction_design_enable',
) );

// Introduction content enable control and setting
$wp_customize->add_setting( 'sociable_pro_theme_options[introduction_section_enable]', array(
	'default'			=> 	$options['introduction_section_enable'],
	'sanitize_callback' => 'sociable_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Sociable_Pro_Switch_Control( $wp_customize, 'sociable_pro_theme_options[introduction_section_enable]', array(
	'label'             => esc_html__( 'Introduction Section Enable', 'sociable-pro' ),
	'section'           => 'sociable_pro_introduction_section',
	'on_off_label' 		=> sociable_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sociable_pro_theme_options[introduction_section_enable]', array(
		'selector'            => '#introduction-section .wrapper .tooltiptext',
		'settings'            => 'sociable_pro_theme_options[introduction_section_enable]',
    ) );
}

// Introduction content type control and setting
$wp_customize->add_setting( 'sociable_pro_theme_options[introduction_content_type]', array(
	'default'          	=> $options['introduction_content_type'],
	'sanitize_callback' => 'sociable_pro_sanitize_select',
) );

$wp_customize->add_control( 'sociable_pro_theme_options[introduction_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'sociable-pro' ),
	'section'           => 'sociable_pro_introduction_section',
	'type'				=> 'select',
	'active_callback' 	=> 'sociable_pro_is_introduction_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'sociable-pro' ),
		'post' 		=> esc_html__( 'Post', 'sociable-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'sociable-pro' ),
	),
) );

// introduction sub title setting and control
$wp_customize->add_setting( 'sociable_pro_theme_options[introduction_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['introduction_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'sociable_pro_theme_options[introduction_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'sociable-pro' ),
	'section'        	=> 'sociable_pro_introduction_section',
	'active_callback' 	=> 'sociable_pro_is_introduction_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sociable_pro_theme_options[introduction_sub_title]', array(
		'selector'            => '#introduction-section .entry-header h4.title',
		'settings'            => 'sociable_pro_theme_options[introduction_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'sociable_pro_introduction_sub_title_partial',
    ) );
}

// introduction pages drop down chooser control and setting
$wp_customize->add_setting( 'sociable_pro_theme_options[introduction_content_page]', array(
	'sanitize_callback' => 'sociable_pro_sanitize_page',
) );

$wp_customize->add_control( new Sociable_Pro_Dropdown_Chooser( $wp_customize, 'sociable_pro_theme_options[introduction_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'sociable-pro' ),
	'section'           => 'sociable_pro_introduction_section',
	'choices'			=> sociable_pro_page_choices(),
	'active_callback'	=> 'sociable_pro_is_introduction_section_content_page_enable',
) ) );

// introduction posts drop down chooser control and setting
$wp_customize->add_setting( 'sociable_pro_theme_options[introduction_content_post]', array(
	'sanitize_callback' => 'sociable_pro_sanitize_page',
) );

$wp_customize->add_control( new Sociable_Pro_Dropdown_Chooser( $wp_customize, 'sociable_pro_theme_options[introduction_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'sociable-pro' ),
	'section'           => 'sociable_pro_introduction_section',
	'choices'			=> sociable_pro_post_choices(),
	'active_callback'	=> 'sociable_pro_is_introduction_section_content_post_enable',
) ) );

// introduction title setting and control
$wp_customize->add_setting( 'sociable_pro_theme_options[introduction_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['introduction_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'sociable_pro_theme_options[introduction_title]', array(
	'label'           	=> esc_html__( 'Title', 'sociable-pro' ),
	'section'        	=> 'sociable_pro_introduction_section',
	'active_callback' 	=> 'sociable_pro_is_introduction_section_content_custom_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sociable_pro_theme_options[introduction_title]', array(
		'selector'            => '#introduction-section .entry-container .entry-header h2.entry-title',
		'settings'            => 'sociable_pro_theme_options[introduction_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'sociable_pro_introduction_title_partial',
    ) );
}

// introduction description setting and control
$wp_customize->add_setting( 'sociable_pro_theme_options[introduction_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['introduction_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'sociable_pro_theme_options[introduction_description]', array(
	'label'           	=> esc_html__( 'Description', 'sociable-pro' ),
	'section'        	=> 'sociable_pro_introduction_section',
	'active_callback' 	=> 'sociable_pro_is_introduction_section_content_custom_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sociable_pro_theme_options[introduction_description]', array(
		'selector'            => '#introduction-section .entry-container .entry-content p',
		'settings'            => 'sociable_pro_theme_options[introduction_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'sociable_pro_introduction_description_partial',
    ) );
}

// introduction image setting and control.
$wp_customize->add_setting( 'sociable_pro_theme_options[introduction_image]', array(
	'sanitize_callback' => 'sociable_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'sociable_pro_theme_options[introduction_image]',
		array(
		'label'       		=> esc_html__( 'Image', 'sociable-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'sociable-pro' ), 1280, 854 ),
		'section'     		=> 'sociable_pro_introduction_section',
		'active_callback'	=> 'sociable_pro_is_introduction_section_content_custom_enable',
) ) );

// introduction btn title setting and control
$wp_customize->add_setting( 'sociable_pro_theme_options[introduction_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['introduction_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'sociable_pro_theme_options[introduction_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'sociable-pro' ),
	'section'        	=> 'sociable_pro_introduction_section',
	'active_callback' 	=> 'sociable_pro_is_introduction_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sociable_pro_theme_options[introduction_btn_title]', array(
		'selector'            => '#introduction-section a.btn',
		'settings'            => 'sociable_pro_theme_options[introduction_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'sociable_pro_introduction_btn_title_partial',
    ) );
}

// introduction btn link setting and control
$wp_customize->add_setting( 'sociable_pro_theme_options[introduction_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'sociable_pro_theme_options[introduction_btn_link]', array(
	'label'           	=> esc_html__( 'Button Link', 'sociable-pro' ),
	'section'        	=> 'sociable_pro_introduction_section',
	'active_callback' 	=> 'sociable_pro_is_introduction_section_content_custom_enable',
	'type'				=> 'url',
) );
