<?php
/**
 * latest_product Section options
 *
 * @package Theme Palace
 * @subpackage sociable Pro
 * @since sociable Pro 1.0.0
 */
if ( !class_exists('WooCommerce') ) {
	return;
}

// Add latest_product section
$wp_customize->add_section( 'sociable_pro_latest_product_section', array(
	'title'             => esc_html__( 'Latest Product','sociable-pro' ),
	'description'       => esc_html__( 'Latest Product Section options.', 'sociable-pro' ),
	'panel'             => 'sociable_pro_front_page_panel',
	'active_callback'	=> 'sociable_pro_is_latest_product_design_enable',
) );

// latest_product content enable control and setting
$wp_customize->add_setting( 'sociable_pro_theme_options[latest_product_section_enable]', array(
	'default'			=> 	$options['latest_product_section_enable'],
	'sanitize_callback' => 'sociable_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Sociable_Pro_Switch_Control( $wp_customize, 'sociable_pro_theme_options[latest_product_section_enable]', array(
	'label'             => esc_html__( 'Latest product Section Enable', 'sociable-pro' ),
	'section'           => 'sociable_pro_latest_product_section',
	'on_off_label' 		=> sociable_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sociable_pro_theme_options[latest_product_section_enable]', array(
        'selector'            => '#latest-products .tooltiptext',
        'settings'            => 'sociable_pro_theme_options[latest_product_section_enable]',
    ) );
}


// latest_product title setting and control
$wp_customize->add_setting( 'sociable_pro_theme_options[latest_product_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['latest_product_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'sociable_pro_theme_options[latest_product_title]', array(
	'label'           	=> esc_html__( 'Title', 'sociable-pro' ),
	'section'        	=> 'sociable_pro_latest_product_section',
	'active_callback' 	=> 'sociable_pro_is_latest_product_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sociable_pro_theme_options[latest_product_title]', array(
		'selector'            => '#latest-products .business-section-header h2',
		'settings'            => 'sociable_pro_theme_options[latest_product_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'sociable_pro_latest_product_title_partial',
    ) );
}

// latest_product title setting and control
$wp_customize->add_setting( 'sociable_pro_theme_options[latest_product_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['latest_product_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'sociable_pro_theme_options[latest_product_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'sociable-pro' ),
	'section'        	=> 'sociable_pro_latest_product_section',
	'active_callback' 	=> 'sociable_pro_is_latest_product_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sociable_pro_theme_options[latest_product_sub_title]', array(
		'selector'            => '#latest-products .business-section-header p',
		'settings'            => 'sociable_pro_theme_options[latest_product_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'sociable_pro_latest_product_sub_title_partial',
    ) );
}

$wp_customize->add_setting( 'sociable_pro_theme_options[latest_product_count]', array(
	'default'          	=> $options['latest_product_count'],
	'sanitize_callback' => 'sociable_pro_sanitize_number_range',
	'validate_callback' => 'sociable_pro_validate_latest_product_count',
) );

$wp_customize->add_control( 'sociable_pro_theme_options[latest_product_count]', array(
	'label'             => esc_html__( 'Number of Product', 'sociable-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'sociable-pro' ),
	'section'           => 'sociable_pro_latest_product_section',
	'active_callback'   => 'sociable_pro_is_latest_product_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

$wp_customize->add_setting( 'sociable_pro_theme_options[latest_product_content_type]', array(
	'default'          	=> $options['latest_product_content_type'],
	'sanitize_callback' => 'sociable_pro_sanitize_select',
) );

$wp_customize->add_control( 'sociable_pro_theme_options[latest_product_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'sociable-pro' ),
	'section'           => 'sociable_pro_latest_product_section',
	'type'				=> 'select',
	'active_callback' 	=> 'sociable_pro_is_latest_product_section_enable',
	'choices'			=> sociable_pro_latest_product_options(),
) );

for( $i = 1 ; $i <= $options['latest_product_count'] ; $i++ ){

	$wp_customize->add_setting( 'sociable_pro_theme_options[latest_product_content_page_' . $i . ']', array(
		'sanitize_callback' => 'sociable_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Sociable_Pro_Dropdown_Chooser( $wp_customize, 'sociable_pro_theme_options[latest_product_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Product %d', 'sociable-pro' ), $i ),
		'section'           => 'sociable_pro_latest_product_section',
		'choices'			=> sociable_pro_product_choices(),
		'active_callback'	=> 'sociable_pro_is_latest_product_section_content_product_enable',
	) ) );
}

$wp_customize->add_setting(  'sociable_pro_theme_options[latest_product_category]', array(
		'sanitize_callback' => 'sociable_pro_sanitize_integers',
	) ) ;

$wp_customize->add_control( new Sociable_Pro_Dropdown_Taxonomies_Control( $wp_customize,'sociable_pro_theme_options[latest_product_category]', array(
	'label'             => esc_html__( 'Select Product Categories', 'sociable-pro' ),
	'description'      	=> esc_html__( 'Note: Press CTRL and select multiple category. Latest four posts will be shown from each selected category', 'sociable-pro' ),
	'section'           => 'sociable_pro_latest_product_section',
	'taxonomy'			=> class_exists('WooCommerce') ? 'product_cat' : 'category',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'sociable_pro_is_latest_product_section_content_product_category_enable',
) ) );