<?php
/**
 * Popular Section options
 *
 * @package Theme Palace
 * @subpackage Sociable Pro
 * @since Sociable Pro 1.0.0
 */

// Add Popular section
$wp_customize->add_section( 'sociable_pro_popular_section', array(
	'title'             => esc_html__( 'Popular','sociable-pro' ),
	'description'       => esc_html__( 'Popular Section options.', 'sociable-pro' ),
	'panel'             => 'sociable_pro_front_page_panel',
	'active_callback' 	=> 'sociable_pro_is_blog_design_enable',
) );

// Popular content enable control and setting
$wp_customize->add_setting( 'sociable_pro_theme_options[popular_section_enable]', array(
	'default'			=> 	$options['popular_section_enable'],
	'sanitize_callback' => 'sociable_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Sociable_Pro_Switch_Control( $wp_customize, 'sociable_pro_theme_options[popular_section_enable]', array(
	'label'             => esc_html__( 'Popular Section Enable', 'sociable-pro' ),
	'section'           => 'sociable_pro_popular_section',
	'on_off_label' 		=> sociable_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sociable_pro_theme_options[popular_section_enable]', array(
		'selector'            => '#popular-posts .tooltiptext',
		'settings'            => 'sociable_pro_theme_options[popular_section_enable]',
    ) );
}

// popular title setting and control
$wp_customize->add_setting( 'sociable_pro_theme_options[popular_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['popular_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'sociable_pro_theme_options[popular_title]', array(
	'label'           	=> esc_html__( 'Title', 'sociable-pro' ),
	'section'        	=> 'sociable_pro_popular_section',
	'active_callback' 	=> 'sociable_pro_is_popular_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sociable_pro_theme_options[popular_title]', array(
		'selector'            => '#popular-posts h2.section-title',
		'settings'            => 'sociable_pro_theme_options[popular_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'sociable_pro_popular_title_partial',
    ) );
}

// Popular content type control and setting
$wp_customize->add_setting( 'sociable_pro_theme_options[popular_column]', array(
	'default'          	=> $options['popular_column'],
	'sanitize_callback' => 'sociable_pro_sanitize_select',
) );

$wp_customize->add_control( 'sociable_pro_theme_options[popular_column]', array(
	'label'             => esc_html__( 'Column Layout', 'sociable-pro' ),
	'section'           => 'sociable_pro_popular_section',
	'type'				=> 'select',
	'active_callback' 	=> 'sociable_pro_is_popular_section_enable',
	'choices'			=> array( 
		'col-2' 	=> esc_html__( 'Two Column', 'sociable-pro' ),
		'col-3' 	=> esc_html__( 'Three Column', 'sociable-pro' ),
		'col-4' 	=> esc_html__( 'Four Column', 'sociable-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'sociable_pro_theme_options[popular_count]', array(
	'default'          	=> $options['popular_count'],
	'sanitize_callback' => 'sociable_pro_sanitize_number_range',
	'validate_callback' => 'sociable_pro_validate_popular_count',
) );

$wp_customize->add_control( 'sociable_pro_theme_options[popular_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'sociable-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'sociable-pro' ),
	'section'           => 'sociable_pro_popular_section',
	'active_callback'   => 'sociable_pro_is_popular_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 2,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Popular content type control and setting
$wp_customize->add_setting( 'sociable_pro_theme_options[popular_content_type]', array(
	'default'          	=> $options['popular_content_type'],
	'sanitize_callback' => 'sociable_pro_sanitize_select',
) );

$wp_customize->add_control( 'sociable_pro_theme_options[popular_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'sociable-pro' ),
	'section'           => 'sociable_pro_popular_section',
	'type'				=> 'select',
	'active_callback' 	=> 'sociable_pro_is_popular_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'sociable-pro' ),
		'post' 		=> esc_html__( 'Post', 'sociable-pro' ),
		'category' 	=> esc_html__( 'Category', 'sociable-pro' ),
		'recent' 	=> esc_html__( 'Recent', 'sociable-pro' ),
	),
) );

for ( $i = 1; $i <= $options['popular_count']; $i++ ) :
	// popular pages drop down chooser control and setting
	$wp_customize->add_setting( 'sociable_pro_theme_options[popular_content_page_' . $i . ']', array(
		'sanitize_callback' => 'sociable_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Sociable_Pro_Dropdown_Chooser( $wp_customize, 'sociable_pro_theme_options[popular_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'sociable-pro' ), $i ),
		'section'           => 'sociable_pro_popular_section',
		'choices'			=> sociable_pro_page_choices(),
		'active_callback'	=> 'sociable_pro_is_popular_section_content_page_enable',
	) ) );

	// popular posts drop down chooser control and setting
	$wp_customize->add_setting( 'sociable_pro_theme_options[popular_content_post_' . $i . ']', array(
		'sanitize_callback' => 'sociable_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Sociable_Pro_Dropdown_Chooser( $wp_customize, 'sociable_pro_theme_options[popular_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'sociable-pro' ), $i ),
		'section'           => 'sociable_pro_popular_section',
		'choices'			=> sociable_pro_post_choices(),
		'active_callback'	=> 'sociable_pro_is_popular_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'sociable_pro_theme_options[popular_content_category]', array(
	'sanitize_callback' => 'sociable_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Sociable_Pro_Dropdown_Taxonomies_Control( $wp_customize,'sociable_pro_theme_options[popular_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'sociable-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'sociable-pro' ),
	'section'           => 'sociable_pro_popular_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'sociable_pro_is_popular_section_content_category_enable'
) ) );

// Add dropdown categories setting and control.
$wp_customize->add_setting( 'sociable_pro_theme_options[popular_category_exclude]', array(
	'sanitize_callback' => 'sociable_pro_sanitize_category_list',
) ) ;

$wp_customize->add_control( new Sociable_Pro_Dropdown_Category_Control( $wp_customize,'sociable_pro_theme_options[popular_category_exclude]', array(
	'label'             => esc_html__( 'Select Excluding Categories', 'sociable-pro' ),
	'description'      	=> esc_html__( 'Note: Select categories to exclude. Press CTRL key select multilple categories.', 'sociable-pro' ),
	'section'           => 'sociable_pro_popular_section',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'sociable_pro_is_popular_section_content_recent_enable'
) ) );