<?php
/**
 * Portfolio Section options
 *
 * @package Theme Palace
 * @subpackage Sociable Pro
 * @since Sociable Pro 1.0.0
 */

// Add Portfolio section
$wp_customize->add_section( 'sociable_pro_portfolio_section', array(
	'title'             => esc_html__( 'Main Portfolio','sociable-pro' ),
	'description'       => esc_html__( 'Portfolio Section options.', 'sociable-pro' ),
	'panel'             => 'sociable_pro_front_page_panel',
	'active_callback'	=>'sociable_pro_is_introduction_design_enable',
) );

// Portfolio content enable control and setting
$wp_customize->add_setting( 'sociable_pro_theme_options[portfolio_section_enable]', array(
	'default'			=> 	$options['portfolio_section_enable'],
	'sanitize_callback' => 'sociable_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Sociable_Pro_Switch_Control( $wp_customize, 'sociable_pro_theme_options[portfolio_section_enable]', array(
	'label'             => esc_html__( 'Portfolio Section Enable', 'sociable-pro' ),
	'section'           => 'sociable_pro_portfolio_section',
	'on_off_label' 		=> sociable_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sociable_pro_theme_options[portfolio_section_enable]', array(
		'selector'            => '.portfolio .tooltiptext',
		'settings'            => 'sociable_pro_theme_options[portfolio_section_enable]',
    ) );
}


$wp_customize->add_setting( 'sociable_pro_theme_options[portfolio_icon]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['portfolio_icon'],
) );

$wp_customize->add_control( new Sociable_Pro_Icon_Picker( $wp_customize, 'sociable_pro_theme_options[portfolio_icon]', array(
	'label'             => esc_html__( 'Select Icon', 'sociable-pro' ),
	'section'           => 'sociable_pro_portfolio_section',
	'active_callback'	=> 'sociable_pro_is_portfolio_section_enable',
) ) );

// Portfolio title setting and control
$wp_customize->add_setting( 'sociable_pro_theme_options[portfolio_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['portfolio_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'sociable_pro_theme_options[portfolio_title]', array(
	'label'           	=> esc_html__( 'Portfolio Title', 'sociable-pro' ),
	'section'        	=> 'sociable_pro_portfolio_section',
	'active_callback' 	=> 'sociable_pro_is_portfolio_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sociable_pro_theme_options[portfolio_title]', array(
		'selector'            => '#our-projects .section-header h2.section-title',
		'settings'            => 'sociable_pro_theme_options[portfolio_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'sociable_pro_portfolio_title_partial',
    ) );
}

// Portfolio description setting and control
$wp_customize->add_setting( 'sociable_pro_theme_options[portfolio_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['portfolio_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'sociable_pro_theme_options[portfolio_description]', array(
	'label'           	=> esc_html__( 'Portfolio Description', 'sociable-pro' ),
	'section'        	=> 'sociable_pro_portfolio_section',
	'active_callback' 	=> 'sociable_pro_is_portfolio_section_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sociable_pro_theme_options[portfolio_description]', array(
		'selector'            => '#our-projects .section-subtitle p',
		'settings'            => 'sociable_pro_theme_options[portfolio_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'sociable_pro_portfolio_description_partial',
    ) );
}


// Add dropdown category setting and control.
$wp_customize->add_setting(  'sociable_pro_theme_options[portfolio_content_category]', array(
	'sanitize_callback' => 'sociable_pro_sanitize_category_list',
) ) ;

$wp_customize->add_control( new Sociable_Pro_Dropdown_Category_Control( $wp_customize,'sociable_pro_theme_options[portfolio_content_category]', array(
	'label'             => esc_html__( 'Select Categories', 'sociable-pro' ),
	'description'      	=> esc_html__( 'Note: Press CTRL and select multiple categories.', 'sociable-pro' ),
	'section'           => 'sociable_pro_portfolio_section',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'sociable_pro_is_portfolio_section_enable'
) ) );

// Portfolio alt btn label setting and control
$wp_customize->add_setting( 'sociable_pro_theme_options[portfolio_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['portfolio_btn_label'],
) );

$wp_customize->add_control( 'sociable_pro_theme_options[portfolio_btn_label]', array(
	'label'           	=> esc_html__( 'Portfolio Button Label', 'sociable-pro' ),
	'section'        	=> 'sociable_pro_portfolio_section',
	'active_callback' 	=> 'sociable_pro_is_portfolio_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sociable_pro_theme_options[portfolio_btn_label]', array(
		'selector'            => '#our-projects .read-more a.btn',
		'settings'            => 'sociable_pro_theme_options[portfolio_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'sociable_pro_portfolio_btn_label_partial',
    ) );
}

// Portfolio alt btn url setting and control
$wp_customize->add_setting( 'sociable_pro_theme_options[portfolio_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'sociable_pro_theme_options[portfolio_btn_url]', array(
	'label'           	=> esc_html__( 'Portfolio Button Url', 'sociable-pro' ),
	'section'        	=> 'sociable_pro_portfolio_section',
	'active_callback' 	=> 'sociable_pro_is_portfolio_section_enable',
	'type'				=> 'url',
) );