<?php
/**
 * Team Section options
 *
 * @package Theme Palace
 * @subpackage Sociable Pro
 * @since Sociable Pro 1.0.0
 */

// Add Team section
$wp_customize->add_section( 'sociable_pro_team_section', array(
	'title'             => esc_html__( 'Teams','sociable-pro' ),
	'description'       => esc_html__( 'Teams Section options.', 'sociable-pro' ),
	'panel'             => 'sociable_pro_front_page_panel',
	'active_callback'	=> 'sociable_pro_is_team_design_enable',
) );

// Team content enable control and setting
$wp_customize->add_setting( 'sociable_pro_theme_options[team_section_enable]', array(
	'default'			=> 	$options['team_section_enable'],
	'sanitize_callback' => 'sociable_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Sociable_Pro_Switch_Control( $wp_customize, 'sociable_pro_theme_options[team_section_enable]', array(
	'label'             => esc_html__( 'Team Section Enable', 'sociable-pro' ),
	'section'           => 'sociable_pro_team_section',
	'on_off_label' 		=> sociable_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sociable_pro_theme_options[team_section_enable]', array(
		'selector'            => '.team .tooltiptext',
		'settings'            => 'sociable_pro_theme_options[team_section_enable]',
    ) );
}

// team title setting and control
$wp_customize->add_setting( 'sociable_pro_theme_options[team_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['team_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'sociable_pro_theme_options[team_title]', array(
	'label'           	=> esc_html__( 'Title', 'sociable-pro' ),
	'section'        	=> 'sociable_pro_team_section',
	'active_callback' 	=> 'sociable_pro_is_team_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sociable_pro_theme_options[team_title]', array(
		'selector'            => '#our-team h2.section-title',
		'settings'            => 'sociable_pro_theme_options[team_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'sociable_pro_team_title_partial',
    ) );
}

// team sub title
$wp_customize->add_setting( 'sociable_pro_theme_options[team_sub_title]', array(
	'default'          	=> $options['team_sub_title'],
	'sanitize_callback' => 'sanitize_textarea_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'sociable_pro_theme_options[team_sub_title]', array(
	'label'             => esc_html__( 'Sub title', 'sociable-pro' ),
	'section'           => 'sociable_pro_team_section',
	'active_callback'	=> 'sociable_pro_is_team_section_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sociable_pro_theme_options[team_sub_title]', array(
		'selector'            => '#our-team .section-subtitle',
		'settings'            => 'sociable_pro_theme_options[team_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'sociable_pro_team_sub_title_partial',
    ) );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'sociable_pro_theme_options[team_count]', array(
	'default'          	=> $options['team_count'],
	'sanitize_callback' => 'sociable_pro_sanitize_number_range',
	'validate_callback' => 'sociable_pro_validate_team_count',
) );

$wp_customize->add_control( 'sociable_pro_theme_options[team_count]', array(
	'label'             => esc_html__( 'Number of Teams', 'sociable-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'sociable-pro' ),
	'section'           => 'sociable_pro_team_section',
	'active_callback'   => 'sociable_pro_is_team_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

// Team content type control and setting
$wp_customize->add_setting( 'sociable_pro_theme_options[team_content_type]', array(
	'default'          	=> $options['team_content_type'],
	'sanitize_callback' => 'sociable_pro_sanitize_select',
) );

$wp_customize->add_control( 'sociable_pro_theme_options[team_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'sociable-pro' ),
	'section'           => 'sociable_pro_team_section',
	'type'				=> 'select',
	'active_callback' 	=> 'sociable_pro_is_team_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'sociable-pro' ),
		'post' 		=> esc_html__( 'Post', 'sociable-pro' ),
		'category' 	=> esc_html__( 'Category', 'sociable-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'sociable-pro' ),
	),
) );

for ( $i = 1; $i <= $options['team_count']; $i++ ) :

	// team pages drop down chooser control and setting
	$wp_customize->add_setting( 'sociable_pro_theme_options[team_content_page_' . $i . ']', array(
		'sanitize_callback' => 'sociable_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Sociable_Pro_Dropdown_Chooser( $wp_customize, 'sociable_pro_theme_options[team_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'sociable-pro' ), $i ),
		'section'           => 'sociable_pro_team_section',
		'choices'			=> sociable_pro_page_choices(),
		'active_callback'	=> 'sociable_pro_is_team_section_content_page_enable',
	) ) );

	// team posts drop down chooser control and setting
	$wp_customize->add_setting( 'sociable_pro_theme_options[team_content_post_' . $i . ']', array(
		'sanitize_callback' => 'sociable_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Sociable_Pro_Dropdown_Chooser( $wp_customize, 'sociable_pro_theme_options[team_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'sociable-pro' ), $i ),
		'section'           => 'sociable_pro_team_section',
		'choices'			=> sociable_pro_post_choices(),
		'active_callback'	=> 'sociable_pro_is_team_section_content_post_enable',
	) ) );


	// team image
	$wp_customize->add_setting( 'sociable_pro_theme_options[team_content_custom_image_' . $i . ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'sociable_pro_theme_options[team_content_custom_image_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Image %d', 'sociable-pro' ), $i ),
		'section'           => 'sociable_pro_team_section',
		'active_callback'   => 'sociable_pro_is_team_section_content_custom_enable',
	) ) );

	// team custom title
	$wp_customize->add_setting( 'sociable_pro_theme_options[team_content_custom_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'sociable_pro_theme_options[team_content_custom_title_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Title %d', 'sociable-pro' ), $i ),
		'section'           => 'sociable_pro_team_section',
		'active_callback'	=> 'sociable_pro_is_team_section_content_custom_enable',
	) );

	// team custom content
	$wp_customize->add_setting( 'sociable_pro_theme_options[team_content_custom_position_' . $i . ']', array(
		'sanitize_callback' => 'wp_kses_post',
	) );

	$wp_customize->add_control( 'sociable_pro_theme_options[team_content_custom_position_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Position %d', 'sociable-pro' ), $i ),
		'section'           => 'sociable_pro_team_section',
		'active_callback'	=> 'sociable_pro_is_team_section_enable',
	) );

	// team social
	$wp_customize->add_setting( 'sociable_pro_theme_options[team_social_' . $i. ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new Sociable_Pro_Multi_Input_Custom_Control( $wp_customize, 'sociable_pro_theme_options[team_social_' . $i. ']', array(
		'label'             => esc_html__( 'Social ', 'sociable-pro' ),
		'button_text'       => esc_html__( 'Add social.', 'sociable-pro' ),
		'section'           => 'sociable_pro_team_section',
		'active_callback' 	=> 'sociable_pro_is_team_section_enable',
	) ) );

	// Separator setting
	$wp_customize->add_setting( 'sociable_pro_theme_options[team_separator_' . $i . ']', array(
		'sanitize_callback' => 'wp_kses_post',
	) );

	$wp_customize->add_control( new Sociable_Pro_Note_Control( $wp_customize, 'sociable_pro_theme_options[team_separator_' . $i . ']', array(
		'label'             => __( '<hr style="width: 100%; border: 1px #bcb1b1 solid;"/>', 'sociable-pro' ),
		'section'           => 'sociable_pro_team_section',
		'active_callback'	=> 'sociable_pro_is_team_section_enable',
		'type'				=> 'custom-html',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'sociable_pro_theme_options[team_content_category]', array(
	'sanitize_callback' => 'sociable_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Sociable_Pro_Dropdown_Taxonomies_Control( $wp_customize,'sociable_pro_theme_options[team_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'sociable-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'sociable-pro' ),
	'section'           => 'sociable_pro_team_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'sociable_pro_is_team_section_content_category_enable'
) ) );
