<?php
/**
 * Youtube Section options
 *
 * @package Theme Palace
 * @subpackage Sociable Pro
 * @since Sociable Pro 1.0.0
 */

// Add Youtube section
$wp_customize->add_section( 'sociable_pro_youtube_section', array(
	'title'             => esc_html__( 'Youtube','sociable-pro' ),
	'description'       => sprintf( sociable_pro_santize_allow_tag('Youtube Section options. <a href="%1$s">click here </a> to link youtube account', 'sociable-pro'), admin_url( $path = '?page=youtube-feed', $scheme = 'admin' ) ),
	'panel'             => 'sociable_pro_front_page_panel',
	'active_callback'   => 'sociable_pro_is_youtube_design_enable',
) );

// Youtube content enable control and setting
$wp_customize->add_setting( 'sociable_pro_theme_options[youtube_section_enable]', array(
	'default'			=> 	$options['youtube_section_enable'],
	'sanitize_callback' => 'sociable_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Sociable_Pro_Switch_Control( $wp_customize, 'sociable_pro_theme_options[youtube_section_enable]', array(
	'label'             => esc_html__( 'Youtube Section Enable', 'sociable-pro' ),
	'section'           => 'sociable_pro_youtube_section',
	'on_off_label' 		=> sociable_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sociable_pro_theme_options[youtube_section_enable]', array(
		'selector'            => '.youtube .tooltiptext',
		'settings'            => 'sociable_pro_theme_options[youtube_section_enable]',
    ) );
}

$wp_customize->add_setting( 'sociable_pro_theme_options[youtube_icon]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['youtube_icon'],
) );

$wp_customize->add_control( new Sociable_Pro_Icon_Picker( $wp_customize, 'sociable_pro_theme_options[youtube_icon]', array(
	'label'             => esc_html__( 'Select Icon', 'sociable-pro' ),
	'section'           => 'sociable_pro_youtube_section',
	'active_callback'	=> 'sociable_pro_is_youtube_section_enable',
) ) );

// Youtube title setting and control
$wp_customize->add_setting( 'sociable_pro_theme_options[youtube_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['youtube_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'sociable_pro_theme_options[youtube_title]', array(
	'label'           	=> esc_html__( 'Youtube Title', 'sociable-pro' ),
	'section'        	=> 'sociable_pro_youtube_section',
	'active_callback' 	=> 'sociable_pro_is_youtube_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sociable_pro_theme_options[youtube_title]', array(
		'selector'            => '#video-section .section-header h2.section-title',
		'settings'            => 'sociable_pro_theme_options[youtube_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'sociable_pro_youtube_title_partial',
    ) );
}

// Youtube description setting and control
$wp_customize->add_setting( 'sociable_pro_theme_options[youtube_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['youtube_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'sociable_pro_theme_options[youtube_description]', array(
	'label'           	=> esc_html__( 'Youtube Description', 'sociable-pro' ),
	'section'        	=> 'sociable_pro_youtube_section',
	'active_callback' 	=> 'sociable_pro_is_youtube_section_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'sociable_pro_theme_options[youtube_description]', array(
		'selector'            => '#video-section .section-subtitle p',
		'settings'            => 'sociable_pro_theme_options[youtube_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'sociable_pro_youtube_description_partial',
    ) );
}

