<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage Sociable Pro
 * @since Sociable Pro 1.0.0
 */

function sociable_pro_product_choices() {
    $full_product_list = array();
    $product_id = array();
    $loop = new WP_Query(array('post_type' => array('product', 'product_variation'), 'posts_per_page' => -1));
    while ($loop->have_posts()) : $loop->the_post();
        $product_id[] = get_the_id();
    endwhile;
    wp_reset_postdata();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'sociable-pro' );
    foreach ( $product_id  as $id ) {
        $choices[ $id ] = get_the_title( $id );
    }
    return  $choices;
}

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function sociable_pro_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'sociable-pro' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = esc_html($page->post_title);
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function sociable_pro_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'sociable-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = esc_html($post->post_title);
    }
    return  $choices;
}

if ( ! function_exists( 'sociable_pro_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function sociable_pro_typography_options(){
        $font_family_arr = array();
        $font_family_arr[''] = esc_html__( '--Default--', 'sociable-pro' );

        // Make the request
        $request = wp_remote_get( get_theme_file_uri( 'assets/webfonts.json' ) );

        if( is_wp_error( $request ) ) {
            return false; // Bail early
        }
        // Retrieve the data
        $body = wp_remote_retrieve_body( $request );
        $data = json_decode( $body );
        if ( ! empty( $data ) ) {
            foreach ( $data->items as $items => $fonts ) {
                $family_str_arr = explode( ' ', $fonts->family );
                $family_value = implode( '+', $family_str_arr );
                $font_family_arr[ $family_value ] = $fonts->family;
            }
        }

        return $font_family_arr;
    }
endif;


if ( ! function_exists( 'sociable_pro_body_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function sociable_pro_body_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'sociable-pro' ),
            'body-font-1'     => esc_html__( 'News Cycle', 'sociable-pro' ),
            'body-font-2'     => esc_html__( 'Pontano Sans', 'sociable-pro' ),
            'body-font-3'     => esc_html__( 'Gudea', 'sociable-pro' ),
            'body-font-4'     => esc_html__( 'Quattrocento', 'sociable-pro' ),
            'body-font-5'     => esc_html__( 'Khand', 'sociable-pro' ),
        );

        $output = apply_filters( 'sociable_pro_body_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'sociable_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function sociable_pro_site_layout() {
        $sociable_pro_site_layout = array(
            'wide'  => get_template_directory_uri() . '/assets/images/full.png',
            'boxed-layout' => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'sociable_pro_site_layout', $sociable_pro_site_layout );
        return $output;
    }
endif;

if ( ! function_exists( 'sociable_pro_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function sociable_pro_selected_sidebar() {
        $sociable_pro_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'sociable-pro' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'sociable-pro' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'sociable-pro' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'sociable-pro' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'sociable-pro' ),
        );

        $output = apply_filters( 'sociable_pro_selected_sidebar', $sociable_pro_selected_sidebar );

        return $output;
    }
endif;


if ( ! function_exists( 'sociable_pro_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function sociable_pro_global_sidebar_position() {
        $sociable_pro_global_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'sociable_pro_global_sidebar_position', $sociable_pro_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'sociable_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function sociable_pro_sidebar_position() {
        $sociable_pro_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
            'no-sidebar-content'   => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'sociable_pro_sidebar_position', $sociable_pro_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'sociable_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function sociable_pro_pagination_options() {
        $sociable_pro_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'sociable-pro' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'sociable-pro' ),
            'infinite'  => esc_html__( 'Infinite', 'sociable-pro' ),
        );

        $output = apply_filters( 'sociable_pro_pagination_options', $sociable_pro_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'sociable_pro_get_spinner_list' ) ) :
    /**
     * List of spinner icons options.
     * @return array List of all spinner icon options.
     */
    function sociable_pro_get_spinner_list() {
        $arr = array(
            'default'               => esc_html__( 'Default', 'sociable-pro' ),
            'spinner-wheel'         => esc_html__( 'Wheel', 'sociable-pro' ),
            'spinner-double-circle' => esc_html__( 'Double Circle', 'sociable-pro' ),
            'spinner-two-way'       => esc_html__( 'Two Way', 'sociable-pro' ),
            'spinner-umbrella'      => esc_html__( 'Umbrella', 'sociable-pro' ),
            'spinner-circle'        => esc_html__( 'Circle', 'sociable-pro' ),
            'spinner-dots'          => esc_html__( 'Dots', 'sociable-pro' ),
            'spinner-one-way'       => esc_html__( 'One Way', 'sociable-pro' ),
            'spinner-fidget'        => esc_html__( 'Fidget', 'sociable-pro' ),
        );
        return apply_filters( 'sociable_pro_spinner_list', $arr );
    }
endif;

if ( ! function_exists( 'sociable_pro_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function sociable_pro_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'sociable-pro' ),
            'off'       => esc_html__( 'Disable', 'sociable-pro' )
        );
        return apply_filters( 'sociable_pro_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'sociable_pro_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function sociable_pro_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'sociable-pro' ),
            'off'       => esc_html__( 'No', 'sociable-pro' )
        );
        return apply_filters( 'sociable_pro_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'sociable_pro_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function sociable_pro_sortable_sections() {
        $sections = array(
            'slider'        => esc_html__( 'Slider', 'sociable-pro' ),
            'introduction'  => esc_html__( 'Introduction', 'sociable-pro' ),
            'latest_product'  => esc_html__( 'Latest Product', 'sociable-pro' ),
           
        );
        return apply_filters( 'sociable_pro_sortable_sections', $sections );
    }
endif;

if ( ! function_exists( 'sociable_pro_recent_product_options' ) ) :
    /**
     * List of recent_product options
     * @return array List of recent_product options.
     */
    function sociable_pro_recent_product_options() {
    
        if ( class_exists( 'WooCommerce' ) ) {
                $arr = array(
                'product'           => esc_html__( 'Product', 'sociable-pro' ),
                'product_cat'       => esc_html__( 'Product Category', 'sociable-pro' ),
                'recent_product'    => esc_html__( 'Recent Product', 'sociable-pro' ),
            );
        }

        return apply_filters( 'sociable_pro_recent_product_options', $arr );
    }
endif;

if ( ! function_exists( 'sociable_pro_latest_product_options' ) ) :
    /**
     * List of latest_product options
     * @return array List of latest_product options.
     */
    function sociable_pro_latest_product_options() {
    
        if ( class_exists( 'WooCommerce' ) ) {
                $arr = array(
                'product'           => esc_html__( 'Product', 'sociable-pro' ),
                'product_cat'       => esc_html__( 'Product Category', 'sociable-pro' ),
                'recent_product'    => esc_html__( 'Recent Product', 'sociable-pro' ),
            );
        }

        return apply_filters( 'sociable_pro_recent_product_options', $arr );
    }
endif;