<?php
/**
 * About section
 *
 * This is the template for the content of about section
 *
 * @package Theme Palace
 * @subpackage Sociable Pro
 * @since Sociable Pro 1.0.0
 */
if ( ! function_exists( 'sociable_pro_add_about_section' ) ) :
    /**
    * Add about section
    *
    *@since Sociable Pro 1.0.0
    */
    function sociable_pro_add_about_section() {
    	$options = sociable_pro_get_theme_options();
        // Check if about is enabled on frontpage
        $about_enable = apply_filters( 'sociable_pro_section_status', true, 'about_section_enable' );

        if ( !in_array( $options['home_layout'], array( 'fourth-design', 'fifth-design', 'sixth-design', 'default-design' ) ) ) {
             $about_enable = false;
        }

        if ( true !== $about_enable ) {
            return false;
        }
        // Get about section details
        $section_details = array();
        $section_details = apply_filters( 'sociable_pro_filter_about_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render about section now.
        sociable_pro_render_about_section( $section_details );
    }
endif;

if ( ! function_exists( 'sociable_pro_get_about_section_details' ) ) :
    /**
    * about section details.
    *
    * @since Sociable Pro 1.0.0
    * @param array $input about section details.
    */
    function sociable_pro_get_about_section_details( $input ) {
        $options = sociable_pro_get_theme_options();

        // Content type.
        $about_content_type  = $options['about_content_type'];
        
        $content = array();
        switch ( $about_content_type ) {
        	
            case 'custom':
                $custom['title']        = ! empty( $options['about_title'] ) ? $options['about_title'] : '';
                $custom['excerpt']      = ! empty( $options['about_description'] ) ? $options['about_description'] : '';
                $custom['image']        = ! empty( $options['about_image'] ) ? $options['about_image'] : '';
                $custom['url']          = ! empty( $options['about_btn_link'] ) ? $options['about_btn_link'] : '';

                // Push to the main array.
                array_push( $content, $custom );
            break;

            case 'page':
                $page_id = ! empty( $options['about_content_page'] ) ? $options['about_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['about_content_post'] ) ? $options['about_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );
            break;

            default:
            break;
        }

        if ( 'custom' !== $about_content_type ) :
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = sociable_pro_trim_content( 50 );
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'medium_large' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        endif;
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// about section content details.
add_filter( 'sociable_pro_filter_about_section_details', 'sociable_pro_get_about_section_details' );


if ( ! function_exists( 'sociable_pro_render_about_section' ) ) :
  /**
   * Start about section
   *
   * @return string about content
   * @since Sociable Pro 1.0.0
   *
   */
   function sociable_pro_render_about_section( $content_details = array() ) {
        $options = sociable_pro_get_theme_options();
        $readmore = ! empty( $options['about_btn_title'] ) ? $options['about_btn_title'] : '';
        $design_layout =  $options['home_layout'] ;
        if ($design_layout=='fourth-design') {
            $design_classes='business';
        }else {
            $design_classes='medical';
        }

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="sociable_pro_about_section">
            <div id="<?php echo $design_classes ?>-about-us" class="about-us relative page-section same-background">
              
                <div class="wrapper">
                      <?php if ( is_customize_preview()): ?>
                            <?php sociable_pro_section_tooltip( 'about-us-class' ); ?>
                        <?php endif ?>
                    <?php foreach ( $content_details as $content ) :  ?>
                        <article class="<?php echo ! empty( $content['image'] ) ? 'has-post-thumbnail' : 'no-featured-image'; ?>">
                            <?php if ( ! empty( $content['image'] ) ) : ?>
                                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">  
                                     <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                                </div><!-- .featured-image -->
                            <?php endif; ?>

                            <div class="entry-container">
                                <?php if ( ! empty( $content['title'] ) ) : ?>
                                    <header class="entry-header">
                                        <h2 class="entry-title"><?php echo esc_html( $content['title'] ); ?></h2>
                                    </header>
                                <?php endif; ?>

                                <?php if ( ! empty( $content['excerpt'] ) ) : ?>
                                    <div class="entry-content">
                                        <?php echo wp_kses_post( $content['excerpt'] ); ?>
                                    </div><!-- .entry-content -->
                                <?php endif; ?>

                                <?php if ( ! empty( $content['url'] ) && !empty( $readmore ) ) : ?>
                                    <div class="business-read-more">
                                        <a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $readmore ); ?></a>
                                    </div><!-- .read-more -->
                                <?php endif; ?>
                            </div><!-- .entry-container -->
                        </article>
                    <?php endforeach;?>
                </div><!-- .wrapper -->
            </div><!-- #business-about-us -->        
        </div>
           
<?php    }
endif;