<?php
/**
 * Blog section
 *
 * This is the template for the content of blog section
 *
 * @package Theme Palace
 * @subpackage Sociable Pro
 * @since Sociable Pro 1.0.0
 */
if ( ! function_exists( 'sociable_pro_add_blog_section' ) ) :
    /**
    * Add blog section
    *
    *@since Sociable Pro 1.0.0
    */
    function sociable_pro_add_blog_section() {
    	$options = sociable_pro_get_theme_options();
        // Check if blog is enabled on frontpage
        $blog_enable = apply_filters( 'sociable_pro_section_status', true, 'blog_section_enable' );

        if ( true !== $blog_enable ) {
            return false;
        }
        // Get blog section details
        $section_details = array();
        $section_details = apply_filters( 'sociable_pro_filter_blog_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render blog section now.
        sociable_pro_render_blog_section( $section_details );
    }
endif;

if ( ! function_exists( 'sociable_pro_get_blog_section_details' ) ) :
    /**
    * blog section details.
    *
    * @since Sociable Pro 1.0.0
    * @param array $input blog section details.
    */
    function sociable_pro_get_blog_section_details( $input ) {
        $options = sociable_pro_get_theme_options();

        // Content type.
        $blog_content_type  = $options['blog_content_type'];
        $blog_count = ! empty( $options['blog_count'] ) ? $options['blog_count'] : 4;
        
        $content = array();
        switch ( $blog_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $blog_count; $i++ ) {
                    if ( ! empty( $options['blog_content_page_' . $i] ) )
                        $page_ids[] = $options['blog_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $blog_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $blog_count; $i++ ) {
                    if ( ! empty( $options['blog_content_post_' . $i] ) )
                        $post_ids[] = $options['blog_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $blog_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['blog_content_category'] ) ? $options['blog_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $blog_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'recent':
                $cat_ids = ! empty( $options['blog_category_exclude'] ) ? $options['blog_category_exclude'] : array();
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $blog_count ),
                    'category__not_in'  => ( array ) $cat_ids,
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['excerpt']   = sociable_pro_trim_content( 25 );
                $page_post['url']       = get_the_permalink();
                $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : '';
                $page_post['author']    = sociable_pro_author();

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// blog section content details.
add_filter( 'sociable_pro_filter_blog_section_details', 'sociable_pro_get_blog_section_details' );


if ( ! function_exists( 'sociable_pro_render_blog_section' ) ) :
  /**
   * Start blog section
   *
   * @return string blog content
   * @since Sociable Pro 1.0.0
   *
   */
   function sociable_pro_render_blog_section( $content_details = array() ) {
        $options = sociable_pro_get_theme_options();
        $column = ! empty( $options['blog_column'] ) ? $options['blog_column'] : 'col-3';
        $readmore = ! empty( $options['blog_btn_title'] ) ? $options['blog_btn_title'] : esc_html__( 'Read More', 'sociable-pro' );
        $design_layout =  $options['home_layout'] ;
        if ($design_layout=='fifth-design') {
            $design_classes='medical-news';
        }elseif($design_layout=='fourth-design' || $design_layout=='sixth-design') {
            $design_classes='business-latest-posts';
        } else{
            $design_classes='latest-posts';
        }

        if ($design_layout=='fifth-design') {
            $blog_classes='section-content';
        }elseif($design_layout=='fourth-design' || $design_layout=='sixth-design' ) {
            $blog_classes='business-section-content';
        } else{
            $blog_classes='archive-blog-wrapper';
        }

        if ($design_layout=='fifth-design') {
            $post_classes='medical-news-item';
        }elseif($design_layout=='fourth-design' || $design_layout=='sixth-design' ) {
            $post_classes='business-post-item';
        } else{
            $post_classes='blog-post-item';
        }

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="sociable_pro_blog_section">
            <div id="<?php echo $design_classes ?>" class="blog-section relative page-section">
                <div class="wrapper">
                    <?php if ( is_customize_preview()): ?>
                        <?php sociable_pro_section_tooltip( 'blog-section-class' ); ?>
                    <?php endif ?>

                    <?php if ( ($design_layout=='default-design' || $design_layout=='first-design' || $design_layout=='third-design' ) && ! empty( $options['blog_icon'] ) ) : ?>
                        <div class="section-icon">
                            <i class="fa <?php echo esc_attr( $options['blog_icon'] ); ?>" ></i>
                        </div><!-- .section-icon -->
                    <?php endif; ?>

                    <?php if ( ! empty( $options['blog_title'] ) ) : ?>
                        <div class="section-header">
                            <h2 class="section-title"><?php echo esc_html( $options['blog_title'] ); ?></h2>
                        </div><!-- .section-header -->
                    <?php endif;

                    if ( ! empty( $options['blog_description'] ) ) : ?>
                        <div class="section-subtitle">
                            <p><?php echo wp_kses_post( $options['blog_description'] ); ?></p>
                        </div><!-- .section-subtitle -->
                    <?php endif; ?>

                    <div class="<?php echo $blog_classes ?> <?php echo esc_attr( $column ); ?> clear">
                        <?php foreach ( $content_details as $content ) : ?>
                            <article>
                                <div class="<?php echo $post_classes ?> <?php echo has_post_thumbnail( $content['id'] ) ? 'has' : 'no'; ?>-post-thumbnail">

                                    <?php if ( ($design_layout!='fourth-design') && ! empty( $content['image'] ) ) : ?>
                                        <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                            <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                                            <?php if ($design_layout=='fifth-design') { ?>
                                                <div class="date"> <?php sociable_pro_posted_on( $content['id'] );  ?> </div>
                                            <?php } ?>
                                        </div><!-- .featured-image -->
                                    <?php endif; 
                                    if ( ($design_layout=='fourth-design' || $design_layout=='sixth-design' ) ) { ?>
                                        <div class="featured-image">
                                            <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['image'] ); ?>"></a>
                                        </div><!-- .featured-image -->
                                    <?php } ?>

                                    <div class="entry-container"> 
                                        <?php if ($design_layout=='default-design' || $design_layout=='first-design' || $design_layout=='third-design') { ?>
                                            <div class="entry-meta">
                                                <?php sociable_pro_posted_on( $content['id'] ); ?>    
                                            </div><!-- .entry-meta -->
                                        <?php } ?>

                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                        </header>

                                        <div class="entry-content">
                                            <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                        </div><!-- .entry-content -->
                           
                                        <?php if ($design_layout=='default-design' || $design_layout=='first-design' || $design_layout=='third-design') { 
                                             echo sociable_pro_article_footer_meta( $content['id'] ); 
                                         }elseif($design_layout=='fifth-design' || $design_layout=='fourth-design' || $design_layout=='sixth-design' ){ ?>
                                            <?php if ($design_layout=='fifth-design') {?>
                                            <div class="post-read-more">
                                                <a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $options['blog_btn_title'] ); ?></a>
                                            </div><!-- .post-read-more -->
                                        <?php }else { ?> 
                                            <div class="entry-meta clear">
                                                <?php sociable_pro_posted_on( $content['id'] );  ?>
                                                <span class="more-link"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $options['blog_btn_title'] ); ?></a></span>
                                            </div> 
                                            <?php } ?>
                                        <?php }?> 

                                    </div><!-- .entry-container -->
                                </div><!-- .facebook-post-item -->
                            </article>
                        <?php endforeach; ?>
                    </div><!-- .archive-blog-wrapper -->

                    <?php if ( ($design_layout=='default-design' || $design_layout=='second-design' || $design_layout=='third-design') && ! empty( $options['blog_btn_title'] ) && ! empty( $options['blog_btn_url'] ) ) : ?>
                        <div class="view-all">
                            <a href="<?php echo esc_url( $options['blog_btn_url'] ); ?>" class="btn"><?php echo esc_html( $options['blog_btn_title'] ); ?></a>
                        </div><!-- .view-all -->
                    <?php endif; ?>

                </div><!-- .wrapper -->
            </div><!-- #latest-posts -->
        </div>
       

    <?php }
endif;