<?php
/**
 * Clients section
 *
 * This is the template for the content of clients section
 *
 * @package Theme Palace
 * @subpackage Sociable Pro
 * @since Sociable Pro 1.0.0
 */
if ( ! function_exists( 'sociable_pro_add_clients_section' ) ) :
    /**
    * Add clients section
    *
    *@since Sociable Pro 1.0.0
    */
    function sociable_pro_add_clients_section() {
    	$options = sociable_pro_get_theme_options();
        // Check if clients is enabled on frontpage
        $clients_enable = apply_filters( 'sociable_pro_section_status', true, 'clients_section_enable' );
        if( in_array( $options['home_layout'], array( 'fourth-design', 'third-design', 'sixth-design' ) ) ){
            $clients_enable = false;
        }

        if ( true !== $clients_enable ) {
            return false;
        }
        // Get clients section details
        $section_details = array();
        $section_details = apply_filters( 'sociable_pro_filter_clients_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render clients section now.
        sociable_pro_render_clients_section( $section_details );
    }
endif;

if ( ! function_exists( 'sociable_pro_get_clients_section_details' ) ) :
    /**
    * clients section details.
    *
    * @since Sociable Pro 1.0.0
    * @param array $input clients section details.
    */
    function sociable_pro_get_clients_section_details( $input ) {
        $options = sociable_pro_get_theme_options();

        // Content type.
        $clients_content_type  = $options['clients_content_type'];
        $clients_count = ! empty( $options['clients_count'] ) ? $options['clients_count'] : 3;
        
        $content = array();
        switch ( $clients_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $clients_count; $i++ ) {
                    if ( ! empty( $options['clients_content_page_' . $i] ) )
                        $page_ids[] = $options['clients_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $clients_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $clients_count; $i++ ) {
                    if ( ! empty( $options['clients_content_post_' . $i] ) )
                        $post_ids[] = $options['clients_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $clients_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['clients_content_category'] ) ? $options['clients_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $clients_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'custom':
                for ( $i = 1; $i <= $clients_count; $i++ ) {
                    $custom['image']        = ! empty( $options['clients_image_' . $i] ) ? $options['clients_image_' . $i] : '';
                    $custom['title']        = ! empty( $options['clients_title_' . $i] ) ? $options['clients_title_' . $i] : '';
                    $custom['url']          = ! empty( $options['clients_url_' . $i] ) ? $options['clients_url_' . $i] : '#';

                    // Push to the main array.
                    array_push( $content, $custom );
                }
            break;

            default:
            break;
        }

        if ( 'custom' !== $clients_content_type ) {
            // Run The Loop.
            $query = new WP_Query( $args );
            $i = 0;
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'medium' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-150x150.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                    $i++;
                endwhile;
            endif;
            wp_reset_postdata();
        }
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// clients section content details.
add_filter( 'sociable_pro_filter_clients_section_details', 'sociable_pro_get_clients_section_details' );


if ( ! function_exists( 'sociable_pro_render_clients_section' ) ) :
  /**
   * Start clients section
   *
   * @return string clients content
   * @since Sociable Pro 1.0.0
   *
   */
   function sociable_pro_render_clients_section( $content_details = array() ) {
        $options = sociable_pro_get_theme_options();
        $column = ! empty( $options['clients_column'] ) ? $options['clients_column'] : 'col-5';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="sociable_pro_clients_section">
            <div id="our-partners" class="relative page-section">
                <div class="wrapper">
                    <?php if ( is_customize_preview()): ?>
                        <?php sociable_pro_section_tooltip( 'our-partners' ); ?>
                    <?php endif ?>

                    <div class="<?php echo esc_attr( $column ); ?>">
                        <?php foreach ( $content_details as $content ) : 
                            if ( ! empty( $content['image'] ) ) : ?>
                                <article><a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['image'] ); ?>" title="<?php echo esc_attr( $content['title'] ); ?>" alt="<?php echo esc_attr( $content['title'] ); ?>"></a></article>
                            <?php endif; 
                        endforeach; ?>
                    </div><!-- .col-5 -->
                </div><!-- .wrapper -->
            </div><!-- #our-partners -->
        </div>
    <?php }
endif;