<?php
/**
 * Counter section
 *
 * This is the template for the content of counter section
 *
 * @package Theme Palace
 * @subpackage Sociable Pro
 * @since Sociable Pro 1.0.0
 */
if ( ! function_exists( 'sociable_pro_add_counter_section' ) ) :
    /**
    * Add counter section
    *
    *@since Sociable Pro 1.0.0
    */
    function sociable_pro_add_counter_section() {
        $options = sociable_pro_get_theme_options();
        // Check if counter is enabled on frontpage
        $counter_enable = apply_filters( 'sociable_pro_section_status', true, 'counter_section_enable' );

        if( !in_array( $options['home_layout'], array( 'fourth-design', 'fifth-design', 'default-design' ) )){
            $counter_enable = false;
        }

        if ( true !== $counter_enable ) {
            return false;
        }

        // Render counter section now.
        sociable_pro_render_counter_section();
    }
endif;

if ( ! function_exists( 'sociable_pro_render_counter_section' ) ) :
  /**
   * Start counter section
   *
   * @return string counter content
   * @since Sociable Pro 1.0.0
   *
   */
   function sociable_pro_render_counter_section() {
        $options = sociable_pro_get_theme_options();
        $image   = empty( $options['counter_image'] ) ? '' : $options['counter_image'] ;
        $column = ! empty( $options['counter_column'] ) ? $options['counter_column'] : 'col-4';
        $contents = array();
        for( $i= 1; $i <=4 ; $i++ ){
            $page_post['icon']      = empty( $options['counter_content_icon_'.$i] ) ? '' : $options['counter_content_icon_'.$i] ;
            $page_post['title']     = empty( $options['counter_title_'.$i] ) ? '' :$options['counter_title_'.$i];
            $page_post['number']    = empty( $options['counter_number_'.$i] ) ? '' :$options['counter_number_'.$i];
            array_push( $contents, $page_post );
        }
       

        ?>
        <div id="sociable_pro_counter_section">
            <div id="business-counter" class="counter relative page-section" style="background-image:url('<?php echo esc_url( $image ) ; ?>');">
                <div class="overlay"></div>
                <div class="wrapper">
                    <?php if ( is_customize_preview()): ?>
                        <?php sociable_pro_section_tooltip( 'counter-class' ); ?>
                    <?php endif ?>
                    <div class="business-section-content <?php echo esc_attr( $column ); ?>">

                        <?php foreach ( $contents as $content ): ?>
                            <?php if ( ! empty( $content['title'] ) || ! empty( $content['icon'] ) || ! empty( $content['number'] ) ): ?>
                                <article>
                                    <header class="entry-header">
                                        <div class="counter-icon">
                                            <i class="fa <?php echo esc_attr( $content['icon'] ) ; ?>"></i>
                                        </div><!-- .counter-icon -->
                                        <h3 class="counter-value">
                                            <?php echo esc_html( $content['number'] ); ?>                                    
                                        </h3>
                                        <div class="separator-line"></div>
                                        <h2 class="entry-title">
                                            <?php echo esc_html( $content['title'] ); ?>    
                                        </h2>
                                    </header>
                                </article>
                            <?php endif ?>                           
                        <?php endforeach ?>
                        </div><!-- .col-4 -->
                </div><!-- .wrapper -->
            </div>
        </div>
            
    <?php }
endif;
