<?php
/**
 * Service section
 *
 * This is the template for the content of features section
 *
 * @package Theme Palace
 * @subpackage Sociable Pro
 * @since Sociable Pro 1.0.0
 */
if ( ! function_exists( 'sociable_pro_add_features_section' ) ) :
    /**
    * Add features section
    *
    *@since Sociable Pro 1.0.0
    */
    function sociable_pro_add_features_section() {
    	$options = sociable_pro_get_theme_options();
        // Check if features is enabled on frontpage
        $features_enable = apply_filters( 'sociable_pro_section_status', true, 'features_section_enable' );

        if( !in_array( $options['home_layout'], array( 'fifth-design', 'default-design' ) )){
            $features_enable = false;
        }

        if ( true !== $features_enable ) {
            return false;
        }
        // Get features section details
        $section_details = array();
        $section_details = apply_filters( 'sociable_pro_filter_features_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render features section now.
        sociable_pro_render_features_section( $section_details );
    }
endif;

if ( ! function_exists( 'sociable_pro_get_features_section_details' ) ) :
    /**
    * features section details.
    *
    * @since Sociable Pro 1.0.0
    * @param array $input features section details.
    */
    function sociable_pro_get_features_section_details( $input ) {
        $options = sociable_pro_get_theme_options();

        // Content type.
        $features_content_type  = $options['features_content_type'];
        $features_count = ! empty( $options['features_count'] ) ? $options['features_count'] : 4;
        
        $content = array();
        switch ( $features_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $features_count; $i++ ) {
                    if ( ! empty( $options['features_content_page_' . $i] ) )
                        $page_ids[] = $options['features_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $features_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $features_count; $i++ ) {
                    if ( ! empty( $options['features_content_post_' . $i] ) )
                        $post_ids[] = $options['features_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $features_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['features_content_category'] ) ? $options['features_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $features_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = sociable_pro_trim_content( 20 );
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// features section content details.
add_filter( 'sociable_pro_filter_features_section_details', 'sociable_pro_get_features_section_details' );


if ( ! function_exists( 'sociable_pro_render_features_section' ) ) :
  /**
   * Start features section
   *
   * @return string features content
   * @since Sociable Pro 1.0.0
   *
   */
   function sociable_pro_render_features_section( $content_details = array() ) {
        $options = sociable_pro_get_theme_options();
        $column = ! empty( $options['features_column'] ) ? $options['features_column'] : 'col-3';
        $design_layout =  $options['home_layout'] ;
        $i = 1;        

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="sociable_pro_features_section">
            <div id="medical-features" class="features relative page-section">
                <div class="wrapper">
                    <?php if ( is_customize_preview()): ?>
                        <?php sociable_pro_section_tooltip( 'features-class' ); ?>
                    <?php endif ?>
                    <?php if ( ((  ! empty( $options['features_title'] ) || ! empty( $options['features_subtitle'] )) ) ) : ?>
                        <div class="section-header">
                            <?php if ( ! empty( $options['features_title'] ) ) : ?>
                                <h2 class="section-title"><?php echo esc_html( $options['features_title'] ); ?></h2>
                            <?php endif; ?>
                            <?php if ( ! empty( $options['features_subtitle'] ) ) : ?>
                                <p class="section-subtitle"><?php echo esc_html( $options['features_subtitle'] ); ?></p>
                            <?php endif; ?>
                        </div><!-- .business-section-header -->
                    <?php endif; ?>

                    <div class="section-content clear <?php echo esc_attr( $column ); ?>">
                        <?php foreach ( $content_details as $content ) : ?>
                        <article>
                            <div class="medical-feature-item" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                    <div class="feature-icon">
                                        <a href="<?php echo esc_url( $content['url'] ); ?>">
                                            <i class="fa <?php echo ! empty( $options['features_content_icon_' . $i] ) ? esc_attr( $options['features_content_icon_' . $i] ) : 'fa-cogs'; ?>"></i>
                                        </a>
                                    </div><!-- .business-features-icon -->
                                    <div class="entry-container">
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>

                                    <div class="entry-content">
                                        <?php echo esc_html( $content['excerpt'] ); ?>
                                    </div><!-- .entry-content -->
                                </div><!-- .entry-container -->
                            </div><!-- .business-features-item -->
                        </article>
                    <?php $i++; endforeach;  ?>
                    </div><!-- .business-section-content -->
                </div><!-- .wrapper -->
            </div><!-- #business-featuress -->
        </div>
        
        
    <?php }
endif;