<?php
/**
 * Instagram section
 *
 * This is the template for the content of instagram section
 *
 * @package Theme Palace
 * @subpackage Sociable Pro
 * @since Sociable Pro 1.0.0
 */
if ( ! function_exists( 'sociable_pro_add_instagram_section' ) ) :
    /**
    * Add instagram section
    *
    *@since Sociable Pro 1.0.0
    */
    function sociable_pro_add_instagram_section() {
    	$options = sociable_pro_get_theme_options();
        // Check if instagram is enabled on frontpage
        $instagram_enable = apply_filters( 'sociable_pro_section_status', true, 'instagram_section_enable' );

        if( !in_array( $options['home_layout'], array( 'second-design', 'default-design' ) )){
            $instagram_enable = false;
        }

        if ( true !== $instagram_enable ) {
            return false;
        }

        // Render instagram section now.
        sociable_pro_render_instagram_section();
    }
endif;

if ( ! function_exists( 'sociable_pro_render_instagram_section' ) ) :
  /**
   * Start instagram section
   *
   * @return string instagram content
   * @since Sociable Pro 1.0.0
   *
   */
   function sociable_pro_render_instagram_section() {
        $options = sociable_pro_get_theme_options();
        $column = ! empty( $options['instagram_column_type'] ) ? $options['instagram_column_type'] : 4;
        $count = ! empty( $options['instagram_count'] ) ? $options['instagram_count'] : 12;
        ?>
        <div id="sociable_pro_instagram_section">
            <div id="instagram-section" class="relative page-section">
                <div class="wrapper">
                    <?php if ( is_customize_preview()): ?>
                        <?php sociable_pro_section_tooltip( 'instagram-section' ); ?>
                    <?php endif ?>
                    <?php if ( ! empty( $options['instagram_icon'] ) ) : ?>
                        <div class="section-icon">
                            <i class="fa <?php echo esc_attr( $options['instagram_icon'] ); ?>" ></i>
                        </div><!-- .section-icon -->
                    <?php endif; ?>

                    <?php if ( ! empty( $options['instagram_title'] ) ) : ?>
                        <div class="section-header">
                            <h2 class="section-title"><?php echo esc_html( $options['instagram_title'] ); ?></h2>
                        </div><!-- .section-header -->
                    <?php endif;

                    if ( ! empty( $options['instagram_description'] ) ) : ?>
                        <div class="section-subtitle">
                            <p><?php echo wp_kses_post( $options['instagram_description'] ); ?></p>
                        </div><!-- .section-subtitle -->
                    <?php endif; ?>

                    <?php echo do_shortcode( '[instagram-feed]' ); ?>

                </div><!-- .wrapper -->
            </div><!-- #instagram-section -->
        </div>
        


    <?php }
endif;