<?php
/**
 * Introduction section
 *
 * This is the template for the content of introduction section
 *
 * @package Theme Palace
 * @subpackage Sociable Pro
 * @since Sociable Pro 1.0.0
 */
if ( ! function_exists( 'sociable_pro_add_introduction_section' ) ) :
    /**
    * Add introduction section
    *
    *@since Sociable Pro 1.0.0
    */
    function sociable_pro_add_introduction_section() {
    	$options = sociable_pro_get_theme_options();
        // Check if introduction is enabled on frontpage
        $introduction_enable = apply_filters( 'sociable_pro_section_status', true, 'introduction_section_enable' );

        if( in_array( $options['home_layout'], array( 'fourth-design', 'fifth-design', 'sixth-design' ) )){
            $introduction_enable = false;
        }

        if ( true !== $introduction_enable ) {
            return false;
        }
        // Get introduction section details
        $section_details = array();
        $section_details = apply_filters( 'sociable_pro_filter_introduction_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render introduction section now.
        sociable_pro_render_introduction_section( $section_details );
    }
endif;

if ( ! function_exists( 'sociable_pro_get_introduction_section_details' ) ) :
    /**
    * introduction section details.
    *
    * @since Sociable Pro 1.0.0
    * @param array $input introduction section details.
    */
    function sociable_pro_get_introduction_section_details( $input ) {
        $options = sociable_pro_get_theme_options();

        // Content type.
        $introduction_content_type  = $options['introduction_content_type'];
        
        $content = array();
        switch ( $introduction_content_type ) {
        	
            case 'custom':
                $custom['title']        = ! empty( $options['introduction_title'] ) ? $options['introduction_title'] : '';
                $custom['excerpt']      = ! empty( $options['introduction_description'] ) ? $options['introduction_description'] : '';
                $custom['image']        = ! empty( $options['introduction_image'] ) ? $options['introduction_image'] : '';
                $custom['url']          = ! empty( $options['introduction_btn_link'] ) ? $options['introduction_btn_link'] : '';

                // Push to the main array.
                array_push( $content, $custom );
            break;

            case 'page':
                $page_id = ! empty( $options['introduction_content_page'] ) ? $options['introduction_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['introduction_content_post'] ) ? $options['introduction_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    'ignore_sticky_posts' => true,
                    );
            break;

            default:
            break;
        }

        if ( 'custom' !== $introduction_content_type ) :
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = sociable_pro_trim_content( 25 );
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        endif;
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// introduction section content details.
add_filter( 'sociable_pro_filter_introduction_section_details', 'sociable_pro_get_introduction_section_details' );


if ( ! function_exists( 'sociable_pro_render_introduction_section' ) ) :
  /**
   * Start introduction section
   *
   * @return string introduction content
   * @since Sociable Pro 1.0.0
   *
   */
   function sociable_pro_render_introduction_section( $content_details = array() ) {
        $options = sociable_pro_get_theme_options();
        $readmore = ! empty( $options['introduction_btn_title'] ) ? $options['introduction_btn_title'] : '';

        if ( empty( $content_details ) ) {
            return;
        } 

        foreach ( $content_details as $content ) : ?>
            <div id="sociable_pro_introduction_section">
                <div id="introduction-section" class="relative page-section">
                    <div class="wrapper">
                        <?php if ( is_customize_preview()): ?>
                            <?php sociable_pro_section_tooltip( 'introduction-section' ); ?>
                        <?php endif ?>
                
                        <article class="<?php echo ! empty( $content['image'] ) ? 'has' : 'no'; ?>-post-thumbnail">

                            <?php if ( ! empty( $content['image'] ) ) : ?>
                                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');"></div>
                            <?php endif; ?>

                            <div class="entry-container">
                               
                                <?php if ( ! empty( $content['title'] ) || ! empty( $options['introduction_sub_title'] ) ) : ?>
                                    <header class="entry-header">
                                        <?php if ( ! empty( $options['introduction_sub_title'] ) ) : ?>
                                            <h4 class="title"><?php echo esc_html( $options['introduction_sub_title'] ); ?></h4>
                                        <?php endif; 

                                        if ( ! empty( $content['title'] ) ) : ?>
                                            <h2 class="entry-title"><a href="<?php echo esc_html( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                        <?php endif; ?>
                                    </header>
                                <?php endif;

                                if ( ! empty( $content['excerpt'] ) ) : ?>
                                    <div class="entry-content">
                                        <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                                    </div><!-- .entry-content -->
                                <?php endif; 

                                if( !empty( $readmore ) ):
                                ?>

                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn"><?php echo esc_html( $readmore ); ?></a>
                            <?php endif; ?>
                            </div><!-- .entry-container -->

                        </article>
                    </div><!-- .wrapper -->
                </div><!-- #introduction-section -->
            </div>
            

        <?php endforeach;
    }
endif;