<?php
/**
 * Blog section
 *
 * This is the template for the content of blog section
 *
 * @package Theme Palace
 * @subpackage Sociable Pro
 * @since Sociable Pro 1.0.0
 */
if ( ! function_exists( 'sociable_pro_add_popular_section' ) ) :
    /**
    * Add blog section
    *
    *@since Sociable Pro 1.0.0
    */
    function sociable_pro_add_popular_section() {
    	$options = sociable_pro_get_theme_options();
        // Check if blog is enabled on frontpage
        $popular_enable = apply_filters( 'sociable_pro_section_status', true, 'popular_section_enable' );

        if( !in_array( $options['home_layout'], array( 'third-design', 'default-design' ) )){
            $popular_enable = false;
        }

        if ( true !== $popular_enable ) {
            return false;
        }
        // Get blog section details
        $section_details = array();
        $section_details = apply_filters( 'sociable_pro_filter_popular_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render blog section now.
        sociable_pro_render_popular_section( $section_details );
    }
endif;

if ( ! function_exists( 'sociable_pro_get_popular_section_details' ) ) :
    /**
    * blog section details.
    *
    * @since Sociable Pro 1.0.0
    * @param array $input blog section details.
    */
    function sociable_pro_get_popular_section_details( $input ) {
        $options = sociable_pro_get_theme_options();

        // Content type.
        $popular_content_type  = $options['popular_content_type'];
        $popular_count = ! empty( $options['popular_count'] ) ? $options['popular_count'] : 4;
        
        $content = array();
        switch ( $popular_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $popular_count; $i++ ) {
                    if ( ! empty( $options['popular_content_page_' . $i] ) )
                        $page_ids[] = $options['popular_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $popular_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $popular_count; $i++ ) {
                    if ( ! empty( $options['popular_content_post_' . $i] ) )
                        $post_ids[] = $options['popular_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $popular_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['popular_content_category'] ) ? $options['popular_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $popular_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'recent':
                $cat_ids = ! empty( $options['popular_category_exclude'] ) ? $options['popular_category_exclude'] : array();
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $popular_count ),
                    'category__not_in'  => ( array ) $cat_ids,
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['excerpt']   = sociable_pro_trim_content( 25 );
                $page_post['url']       = get_the_permalink();
                $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : '';
                $page_post['author']    = sociable_pro_author();

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// blog section content details.
add_filter( 'sociable_pro_filter_popular_section_details', 'sociable_pro_get_popular_section_details' );


if ( ! function_exists( 'sociable_pro_render_popular_section' ) ) :
  /**
   * Start blog section
   *
   * @return string blog content
   * @since Sociable Pro 1.0.0
   *
   */
   function sociable_pro_render_popular_section( $content_details = array() ) {
        $options = sociable_pro_get_theme_options();
        $popular_content_type  = $options['popular_content_type'];
        $column = ! empty( $options['popular_column'] ) ? $options['popular_column'] : 'col-4';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="sociable_pro_popular_section">
            <div id="popular-posts" class="relative page-section">
                <div class="wrapper">
                    <?php if ( is_customize_preview()): ?>
                        <?php sociable_pro_section_tooltip( 'popular-posts' ); ?>
                    <?php endif ?>
                    <div class="section-icon">
                        <i class="fa fa-newspaper-o"></i>
                    </div><!-- .section-icon -->

                     <?php if ( ! empty( $options['popular_title'] ) ) : ?>
                            <div class="section-header">
                                <h2 class="section-title"><?php echo esc_html( $options['popular_title'] ); ?></h2>
                            </div><!-- .section-header -->
                        <?php endif; ?>

                    <div class="section-content <?php echo esc_attr( $column ); ?> clear">
                        <?php foreach ( $content_details as $content ):  ?>
                        <article>
                            <div class="popular-post-item">
                                <div class="featured-image" style="background-image: url('<?php echo esc_url($content['image']); ?>');">
                                    <a href="<?php echo esc_url( $content['url'] ) ; ?>" class="post-thumbnail-link"></a>
                                </div><!-- .featured-image -->

                                <div class="entry-container">

                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ) ; ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>

                                    <?php sociable_pro_posted_on( $content['id'] ); ?>
                                </div><!-- .entry-container -->
                            </div><!-- .popular-post-item -->
                        </article>
                        <?php endforeach; ?>
                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div><!-- #popular-posts -->
        </div>
       
    <?php }
endif;