<?php
/**
 * Reason section
 *
 * This is the template for the content of reason section
 *
 * @package Theme Palace
 * @subpackage Sociable Pro
 * @since Sociable Pro 1.0.0
 */
if ( ! function_exists( 'sociable_pro_add_reason_section' ) ) :
    /**
    * Add reason section
    *
    *@since Sociable Pro 1.0.0
    */
    function sociable_pro_add_reason_section() {
    	$options = sociable_pro_get_theme_options();
        // Check if reason is enabled on frontpage
        $reason_enable = apply_filters( 'sociable_pro_section_status', true, 'reason_section_enable' );

        if( !in_array( $options['home_layout'], array( 'fifth-design', 'default-design' ) )){
            $reason_enable = false;
        }

        if ( true !== $reason_enable ) {
            return false;
        }
        // Get reason section details
        $section_details = array();
        $section_details = apply_filters( 'sociable_pro_filter_reason_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render reason section now.
        sociable_pro_render_reason_section( $section_details );
    }
endif;

if ( ! function_exists( 'sociable_pro_get_reason_section_details' ) ) :
    /**
    * reason section details.
    *
    * @since Sociable Pro 1.0.0
    * @param array $input reason section details.
    */
    function sociable_pro_get_reason_section_details( $input ) {
        $options = sociable_pro_get_theme_options();

        // Content type.
        $reason_content_type  = $options['reason_content_type'];
        
        $content = array();
        switch ( $reason_content_type ) {
        	
            case 'custom':
                $custom['title']        = ! empty( $options['reason_title'] ) ? $options['reason_title'] : '';
                $custom['excerpt']      = ! empty( $options['reason_description'] ) ? $options['reason_description'] : '';
                $custom['image']        = ! empty( $options['reason_image'] ) ? $options['reason_image'] : '';
                $custom['url']          = ! empty( $options['reason_btn_link'] ) ? $options['reason_btn_link'] : '';

                // Push to the main array.
                array_push( $content, $custom );
            break;

            case 'page':
                $page_id = ! empty( $options['reason_content_page'] ) ? $options['reason_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['reason_content_post'] ) ? $options['reason_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );
            break;

            default:
            break;
        }

        if ( 'custom' !== $reason_content_type ) :
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = sociable_pro_trim_content( 50 );
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'medium_large' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        endif;
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// reason section content details.
add_filter( 'sociable_pro_filter_reason_section_details', 'sociable_pro_get_reason_section_details' );


if ( ! function_exists( 'sociable_pro_render_reason_section' ) ) :
  /**
   * Start reason section
   *
   * @return string reason content
   * @since Sociable Pro 1.0.0
   *
   */
   function sociable_pro_render_reason_section( $content_details = array() ) {
        $options = sociable_pro_get_theme_options();
        $reason_background_image =  $options['reason_background_image'] ;
        $design_layout =  $options['home_layout'] ;

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="sociable_pro_reason_section">
            <div id="medical-reasons" class="reasons relative page-section">
                <div class="wrapper">
                    
                    <?php foreach ( $content_details as $content ) :  ?>
                        <article class="<?php echo ! empty( $content['image'] ) ? 'has-post-thumbnail' : 'no-featured-image'; ?>">
                            <?php if ( ! empty( $content['image'] ) ) : ?>
                                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">  
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                                </div><!-- .featured-image -->
                            <?php endif; ?>

                            <div class="entry-container" <?php if (!empty($reason_background_image)) { ?> style="background-image: url('<?php echo esc_url( $reason_background_image ); ?>');" <?php } ?>>
                                <?php if ( is_customize_preview()): ?>
                                    <?php sociable_pro_section_tooltip( 'reasons-class' ); ?>
                                <?php endif ?>
                                <?php if ( ! empty( $content['title'] ) ) : ?>
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>
                                <?php endif; ?>

                                <?php if ( ! empty( $content['excerpt'] ) ) : ?>
                                    <div class="entry-content">
                                        <?php echo wp_kses_post( $content['excerpt'] ); ?>
                                    </div><!-- .entry-content -->
                                <?php endif; ?>
                                <ul>
                                    <?php 
                                    $reason_lists = ! empty( $options['reason_list'] ) ? explode( '|', $options['reason_list'] ) : array(); 

                                    foreach ( $reason_lists as $reason_list ) : ?>
                                        <li><?php echo esc_html( $reason_list ); ?></li>
                                    <?php endforeach; ?>
                                </ul>
                            </div><!-- .entry-container -->
                        </article>
                    <?php endforeach;?>
                </div><!-- .wrapper -->
            </div><!-- #business-reason-us -->        
        </div>
            
<?php    }
endif;