<?php
/**
 * Theme Palace basic theme structure hooks
 *
 * This file contains structural hooks.
 *
 * @package Theme Palace
 * @subpackage Sociable Pro
 * @since Sociable Pro 1.0.0
 */

$options = sociable_pro_get_theme_options();


if ( ! function_exists( 'sociable_pro_doctype' ) ) :
	/**
	 * Doctype Declaration.
	 *
	 * @since Sociable Pro 1.0.0
	 */
	function sociable_pro_doctype() {
	?>
		<!DOCTYPE html>
			<html <?php language_attributes(); ?>>
	<?php
	}
endif;

add_action( 'sociable_pro_doctype', 'sociable_pro_doctype', 10 );


if ( ! function_exists( 'sociable_pro_head' ) ) :
	/**
	 * Header Codes
	 *
	 * @since Sociable Pro 1.0.0
	 *
	 */
	function sociable_pro_head() {
		?>
		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
		<link rel="profile" href="http://gmpg.org/xfn/11">
		<?php if ( is_singular() && pings_open( get_queried_object() ) ) : ?>
			<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">
		<?php endif;
	}
endif;
add_action( 'sociable_pro_before_wp_head', 'sociable_pro_head', 10 );

if ( ! function_exists( 'sociable_pro_page_start' ) ) :
	/**
	 * Page starts html codes
	 *
	 * @since Sociable Pro 1.0.0
	 *
	 */
	function sociable_pro_page_start() {
		?>
		<div id="page" class="site">
			<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'sociable-pro' ); ?></a>
			<div class="menu-overlay"></div>

		<?php
	}
endif;
add_action( 'sociable_pro_page_start_action', 'sociable_pro_page_start', 10 );


if ( ! function_exists( 'sociable_pro_page_end' ) ) :
	/**
	 * Page end html codes
	 *
	 * @since Sociable Pro 1.0.0
	 *
	 */
	function sociable_pro_page_end() {
		?>
		</div><!-- #page -->
		<?php
	}
endif;
add_action( 'sociable_pro_page_end_action', 'sociable_pro_page_end', 10 );

if ( ! function_exists( 'sociable_pro_header_start' ) ) :
	/**
	 * Header start html codes
	 *
	 * @since Sociable Pro 1.0.0
	 *
	 */
	function sociable_pro_header_start() { 
		$options  = sociable_pro_get_theme_options();
		?>
		<?php if ( $options['topbar_section_enable'] == true && ( ! empty( $options['topbar_email'] ) || ! empty( $options['topbar_phone'] ) || ! empty( $options['topbar_address'] ) ) ) : ?>
			<div id="top-bar" class="relative">
	            <svg viewBox="0 0 284.929 284.929" class="dropdown-icon icon-up">
	                <path d="M282.082,195.285L149.028,62.24c-1.901-1.903-4.088-2.856-6.562-2.856s-4.665,0.953-6.567,2.856L2.856,195.285C0.95,197.191,0,199.378,0,201.853c0,2.474,0.953,4.664,2.856,6.566l14.272,14.271c1.903,1.903,4.093,2.854,6.567,2.854c2.474,0,4.664-0.951,6.567-2.854l112.204-112.202l112.208,112.209c1.902,1.903,4.093,2.848,6.563,2.848c2.478,0,4.668-0.951,6.57-2.848l14.274-14.277c1.902-1.902,2.847-4.093,2.847-6.566C284.929,199.378,283.984,197.188,282.082,195.285z"></path>
	            </svg>
	            <svg viewBox="0 0 129 129" class="dropdown-icon icon-down">
	                <path d="m121.3,34.6c-1.6-1.6-4.2-1.6-5.8,0l-51,51.1-51.1-51.1c-1.6-1.6-4.2-1.6-5.8,0-1.6,1.6-1.6,4.2 0,5.8l53.9,53.9c0.8,0.8 1.8,1.2 2.9,1.2 1,0 2.1-0.4 2.9-1.2l53.9-53.9c1.7-1.6 1.7-4.2 0.1-5.8z"></path>
	            </svg>

	            <div class="wrapper">
	                <ul class="contact-info clear">
	                    <?php if ( ! empty( $options['topbar_address'] ) ) : ?>
		                    <li><a href="tel:<?php echo esc_attr( $options['topbar_address'] ); ?>">
		                        <?php echo sociable_pro_get_svg( array( 'icon' => 'location' ) ); ?>
		                        <?php echo esc_html( $options['topbar_address'] ); ?></a>
		                    </li>
		                <?php endif; ?>
	                    <?php if ( ! empty( $options['topbar_phone'] ) ) : ?>
		                    <li><a href="tel:<?php echo esc_attr( $options['topbar_phone'] ); ?>">
		                        <?php echo sociable_pro_get_svg( array( 'icon' => 'phone' ) ); ?>
		                        <?php echo esc_html( $options['topbar_phone'] ); ?></a>
		                    </li>
		                <?php endif; ?>
	                    <?php if ( ! empty( $options['topbar_email'] ) ) : ?>
		                    <li><a href="mailto:<?php echo esc_url( $options['topbar_email'] ); ?>">
		                        <?php echo sociable_pro_get_svg( array( 'icon' => 'envelope-o' ) ); ?>
		                        <?php echo esc_html( $options['topbar_email'] ); ?></a>
		                    </li>
		                <?php endif; ?>
	                </ul><!-- .contact-info -->
	            </div><!-- .wrapper -->
	        </div><!-- #top-bar -->

		<?php endif; ?>
		<header id="masthead" class="site-header" role="banner">
	
			<div class="wrapper">
				<div class="site-menu">
					<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false">
						<?php
							echo sociable_pro_get_svg( array( 'icon' => 'menu' ) );
							echo sociable_pro_get_svg( array( 'icon' => 'close' ) );
						?>					
					</button>
		<?php
	}
endif;
add_action( 'sociable_pro_header_action', 'sociable_pro_header_start', 10 );

if ( ! function_exists( 'sociable_pro_site_branding' ) ) :
	/**
	 * Site branding codes
	 *
	 * @since Sociable Pro 1.0.0
	 *
	 */
	function sociable_pro_site_branding() {
		$options  = sociable_pro_get_theme_options();
		$header_txt_logo_extra = $options['header_txt_logo_extra'];		
		?>
		<div class="site-branding">
			<?php if ( in_array( $header_txt_logo_extra, array( 'show-all', 'logo-title', 'logo-tagline' ) )  ) { ?>
				<div class="site-logo">
					<?php the_custom_logo(); ?>
				</div>
			<?php } 
			if ( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title', 'show-all', 'tagline-only', 'logo-tagline' ) ) ) : ?>
				<div id="site-details">
					<?php
					if( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title' ) )  ) {
						if ( sociable_pro_is_latest_posts() ) : ?>
							<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
						<?php else : ?>
							<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
						<?php
						endif;
					} 
					if ( in_array( $header_txt_logo_extra, array( 'show-all', 'tagline-only', 'logo-tagline' ) ) ) {
						$description = get_bloginfo( 'description', 'display' );
						if ( $description || is_customize_preview() ) : ?>
							<p class="site-description"><?php echo  $description; /* WPCS: xss ok. */ ?></p>
						<?php
						endif; 
					}?>
				</div>
        	<?php endif; ?>
		</div><!-- .site-branding -->
		<?php
	}
endif;
add_action( 'sociable_pro_header_action', 'sociable_pro_site_branding', 20 );

if ( ! function_exists( 'sociable_pro_site_navigation' ) ) :
	/**
	 * Site navigation codes
	 *
	 * @since Sociable Pro 1.0.0
	 *
	 */
	function sociable_pro_site_navigation() {
		$options = sociable_pro_get_theme_options();
		?>
		<nav id="site-navigation" class="main-navigation" role="navigation">
				<?php 
				$social_nav = '';
				if ( $options['header_meta_social_enable'] ) : 
		            $social_nav .= '<li class="social-menu-item">';
		            $social_nav .= '<div class="social-icons">';
		            
            	
            		$social_nav .= wp_nav_menu( 

            			array(
            			'theme_location' => 'social',
            			'container' => false,
            			'menu_class' => '',
            			'echo' => false,
            			'fallback_cb' => 'sociable_pro_menu_fallback_cb',
            			'depth' => 1,
            			'link_before' => '<span class="screen-reader-text">',
						'link_after' => '</span>',
            		)

            		 );
            		$social_nav .= '</div>';
		            $social_nav .= '</li><!-- .social-menu -->';
            	endif; 

        		$defaults = array(
        			'theme_location' => 'primary',
        			'container' => 'div',
        			'menu_class' => 'menu nav-menu',
        			'menu_id' => 'primary-menu',
        			'echo' => true,
        			'fallback_cb' => 'sociable_pro_menu_fallback_cb',
        			'items_wrap' => '<ul id="%1$s" class="%2$s">%3$s' . $social_nav . '</ul>',
        		);
        	
        		wp_nav_menu( $defaults );
        	?>
		</nav><!-- #site-navigation -->
		<?php
	}
endif;
add_action( 'sociable_pro_header_action', 'sociable_pro_site_navigation', 30 );

if ( ! function_exists( 'sociable_pro_social_navigation' ) ) :
	/**
	 * Site navigation codes
	 *
	 * @since Sociable Pro 1.0.0
	 *
	 */
	function sociable_pro_social_navigation() {
		$options = sociable_pro_get_theme_options();
		if ( ! $options['header_meta_social_enable'] )
			return;
		?>
		<div id="social-navigation">
            <div class="social-icons">
				<?php 
	        		$defaults = array(
	            			'theme_location' => 'social',
	            			'container' => false,
	            			'menu_class' => '',
	            			'echo' => true,
	            			'fallback_cb' => 'sociable_pro_menu_fallback_cb',
	            			'depth' => 1,
	            			'link_before' => '<span class="screen-reader-text">',
							'link_after' => '</span>',
	            		);
	        	
	        		wp_nav_menu( $defaults );
	        	?>
			</div><!-- #social-icons -->
		</div><!-- #social-navigation -->
	<?php
	}
endif;
add_action( 'sociable_pro_header_action', 'sociable_pro_social_navigation', 40 );


if ( ! function_exists( 'sociable_pro_header_end' ) ) :
	/**
	 * Header end html codes
	 *
	 * @since Sociable Pro 1.0.0
	 *
	 */
	function sociable_pro_header_end() {
		?>
				</div><!-- .site-menu -->
			</div><!-- .wrapper -->
		</header><!-- #masthead -->
		<?php
	}
endif;

add_action( 'sociable_pro_header_action', 'sociable_pro_header_end', 50 );

if ( ! function_exists( 'sociable_pro_content_start' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Sociable Pro 1.0.0
	 *
	 */
	function sociable_pro_content_start() {
		?>
		<div id="content" class="site-content">
		<?php
	}
endif;
add_action( 'sociable_pro_content_start_action', 'sociable_pro_content_start', 10 );

if ( ! function_exists( 'sociable_pro_header_image' ) ) :
	/**
	 * Header Image codes
	 *
	 * @since Sociable Pro 1.0.0
	 *
	 */
	function sociable_pro_header_image() {
		if ( sociable_pro_is_frontpage() )
			return;
		$header_image = get_header_image();
		if ( is_singular() ) :
			$header_image = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : $header_image;
		endif;
		?>

		<div id="page-site-header" class="relative" style="background-image: url('<?php echo esc_url( $header_image ); ?>');">
            <div class="overlay"></div>
            <div class="wrapper">
                <header class="page-header">
                    <h2 class="page-title"><?php echo sociable_pro_custom_header_banner_title(); ?></h2>
                </header>

                <?php sociable_pro_add_breadcrumb(); ?>
            </div><!-- .wrapper -->
        </div><!-- #page-site-header -->
		<?php
	}
endif;
add_action( 'sociable_pro_header_image_action', 'sociable_pro_header_image', 10 );

if ( ! function_exists( 'sociable_pro_add_breadcrumb' ) ) :
	/**
	 * Add breadcrumb.
	 *
	 * @since Sociable Pro 1.0.0
	 */
	function sociable_pro_add_breadcrumb() {
		$options = sociable_pro_get_theme_options();
		// Bail if Breadcrumb disabled.
		$breadcrumb = $options['breadcrumb_enable'];
		if ( false === $breadcrumb ) {
			return;
		}
		
		// Bail if Home Page.
		if ( sociable_pro_is_frontpage() ) {
			return;
		}

		echo '<div id="breadcrumb-list">';
				/**
				 * sociable_pro_simple_breadcrumb hook
				 *
				 * @hooked sociable_pro_simple_breadcrumb -  10
				 *
				 */
				do_action( 'sociable_pro_simple_breadcrumb' );
		echo '</div><!-- #breadcrumb-list -->';
		return;
	}
endif;

if ( ! function_exists( 'sociable_pro_content_end' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Sociable Pro 1.0.0
	 *
	 */
	function sociable_pro_content_end() {
		?>
			<div class="menu-overlay"></div>
		</div><!-- #content -->
		<?php
	}
endif;
add_action( 'sociable_pro_content_end_action', 'sociable_pro_content_end', 10 );

if ( ! function_exists( 'sociable_pro_footer_start' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Sociable Pro 1.0.0
	 *
	 */
	function sociable_pro_footer_start() {
		?>
		<footer id="colophon" class="site-footer" role="contentinfo">
		<?php
	}
endif;
add_action( 'sociable_pro_footer', 'sociable_pro_footer_start', 10 );

if ( ! function_exists( 'sociable_pro_footer_site_info' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Sociable Pro 1.0.0
	 *
	 */
	function sociable_pro_footer_site_info() {
		$options = sociable_pro_get_theme_options();
		$search = array( '[the-year]', '[site-link]' );

        $replace = array( date( 'Y' ), '<a href="'. esc_url( home_url( '/' ) ) .'">'. esc_attr( get_bloginfo( 'name', 'display' ) ) . '</a>' );

        $options['copyright_text'] = str_replace( $search, $replace, $options['copyright_text'] );

		$copyright_text = $options['copyright_text']; 
		?>
		<div class="site-info col-2">
            <div class="wrapper">
            	<div class="site-wrapper copyright">
	                <span>
	                	<?php 
	                	echo sociable_pro_santize_allow_tag( $copyright_text ); 
	                	if ( function_exists( 'the_privacy_policy_link' ) ) {
							the_privacy_policy_link( ' | ' );
						}
	                	?>
	            	</span>

	            	<span>
                        <?php  
                        	$defaults = array(
	            			'theme_location' => 'social',
	            			'container' => false,
	            			'menu_class' => 'social-icons',
	            			'echo' => true,
	            			'fallback_cb' => 'sociable_pro_menu_fallback_cb',
	            			'depth' => 1,
	            			'link_before' => '<span class="screen-reader-text">',
							'link_after' => '</span>',
	            		);
	            	
	            		wp_nav_menu( $defaults );
                        ?>
                    </span>
            	</div><!-- .site-wrapper --> 
            </div><!-- .wrapper -->    
        </div><!-- .site-info -->

		<?php
	}
endif;
add_action( 'sociable_pro_footer', 'sociable_pro_footer_site_info', 40 );

if ( ! function_exists( 'sociable_pro_footer_scroll_to_top' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Sociable Pro 1.0.0
	 *
	 */
	function sociable_pro_footer_scroll_to_top() {
		$options  = sociable_pro_get_theme_options();
		if ( true === $options['scroll_top_visible'] ) : ?>
			<div class="backtotop"><?php echo sociable_pro_get_svg( array( 'icon' => 'up' ) ); ?></div>
		<?php endif;
	}
endif;
add_action( 'sociable_pro_footer', 'sociable_pro_footer_scroll_to_top', 40 );

if ( ! function_exists( 'sociable_pro_footer_end' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Sociable Pro 1.0.0
	 *
	 */
	function sociable_pro_footer_end() {
		?>
		</footer>
		<div class="popup-overlay"></div>
		<?php
	}
endif;
add_action( 'sociable_pro_footer', 'sociable_pro_footer_end', 100 );

if ( ! function_exists( 'sociable_pro_loader' ) ) :
	/**
	 * Start div id #loader
	 *
	 * @since Sociable Pro 1.0.0
	 *
	 */
	function sociable_pro_loader() {
		$options = sociable_pro_get_theme_options();
		if ( $options['loader_enable'] ) { ?>

			<div id="loader">
            <div class="loader-container">
            	<?php if ( 'default' == $options['loader_icon'] ) : ?>
	                <div id="preloader">
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                </div>
	            <?php else :
	            	echo sociable_pro_get_svg( array( 'icon' => esc_attr( $options['loader_icon'] ) ) );
	            endif; ?>
            </div>
        </div><!-- #loader -->
		<?php }
	}
endif;
add_action( 'sociable_pro_before_header', 'sociable_pro_loader', 10 );

if ( ! function_exists( 'sociable_pro_infinite_loader_spinner' ) ) :
	/**
	 *
	 * @since Sociable Pro 1.0.0
	 *
	 */
	function sociable_pro_infinite_loader_spinner() { 
		global $post;
		$options = sociable_pro_get_theme_options();
		if ( $options['pagination_type'] == 'infinite' ) :
			if ( count( ( array ) $post ) > 0 ) {
				echo '<div class="blog-loader">' . sociable_pro_get_svg( array( 'icon' => 'spinner-umbrella' ) ) . '</div>';
			}
		endif;
	}
endif;
add_action( 'sociable_pro_infinite_loader_spinner_action', 'sociable_pro_infinite_loader_spinner', 10 );
